# This file is part of fedmsg.
# Copyright (C) 2012-2014 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Ralph Bean <rbean@redhat.com>
#
""" Tests for fedmsg.meta """

import unittest

from fedmsg_meta_fedora_infrastructure.tests.base import Base

from fedmsg_meta_fedora_infrastructure.tests.common import add_doc


class LegacyTestBodhiUpdateComplete(Base):
    """ The `Bodhi Updates System <https://admin.fedoraproject.org/updates>`_
    publishes messages on this topic whenever an update
    **completes it's push to the testing repository**.  Here's a
    straightforward example:

    .. note:: We *used* to have this message in our system, but it got removed
       when we found that fedmsg caused the bodhi1 masher to segfault in
       certain circumstances.  This message, or one like it will likely return
       with the advent of bodhi2.
    """
    expected_title = "bodhi.update.complete.testing"
    expected_subti = "ralph's fedmsg-0.2.7-2.el6 bodhi update " + \
        "completed push to testing"
    expected_link = "https://admin.fedoraproject.org/updates/" + \
        "fedmsg-0.2.7-2.el6"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c" + \
        "?s=64&d=retro"
    expected_usernames = set(['ralph'])
    expected_packages = set(['fedmsg'])
    expected_objects = set(['packages/fedmsg'])

    msg = {
        "i": 88,
        "timestamp": 1344447839.891876,
        "topic": "org.fedoraproject.prod.bodhi.update.complete.testing",
        "msg": {
            "update": {
                "close_bugs": True,
                "critpath": False,
                "stable_karma": 3,
                "date_pushed": 1344447839.0,
                "title": "fedmsg-0.2.7-2.el6",
                "nagged": None,
                "comments": [
                    {
                        "group": None,
                        "author": "bodhi",
                        "text": "This update has been submitted for " +
                        "testing by ralph. ",
                        "karma": 0,
                        "anonymous": False,
                        "timestamp": 1344266157.0
                    },
                    {
                        "group": None,
                        "author": "bodhi",
                        "text": "This update is currently being pushed " +
                        "to the Fedora EPEL 6 testing updates " +
                        "repository.",
                        "karma": 0,
                        "anonymous": False,
                        "timestamp": 1344443927.0
                    }
                ],
                "updateid": "FEDORA-EPEL-2012-6650",
                "type": "bugfix",
                "status": "testing",
                "date_submitted": 1344266152.0,
                "unstable_karma": -3,
                "release": {
                    "dist_tag": "dist-6E-epel",
                    "id_prefix": "FEDORA-EPEL",
                    "locked": False,
                    "name": "EL-6",
                    "long_name": "Fedora EPEL 6"
                },
                "approved": None,
                "builds": [
                    {
                        "nvr": "fedmsg-0.2.7-2.el6",
                        "package": {
                            "suggest_reboot": False,
                            "committers": [
                                "ralph"
                            ],
                            "name": "fedmsg"
                        }
                    }
                ],
                "date_modified": None,
                "notes": "Bugfix - Added a forgotten new " +
                "requirement on python-requests.",
                "request": None,
                "bugs": [],
                "critpath_approved": False,
                "karma": 0,
                "submitter": "ralph",
            }
        }
    }


class TestBodhiUpdateEject(Base):
    """ The `Bodhi Updates System <https://admin.fedoraproject.org/updates>`_
    publishes messages on this topic whenever an update
    **is ejected from the mash** due to some failure:
    """
    expected_title = "bodhi.update.eject"
    expected_subti = "ralph's fedmsg-0.2.7-2.el6 bodhi update " + \
        "was ejected from the test_repo mash.  Reason: \"some reason\""
    expected_link = "https://admin.fedoraproject.org/updates/" + \
        "fedmsg-0.2.7-2.el6"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c" + \
        "?s=64&d=retro"
    expected_usernames = set(['ralph'])
    expected_packages = set(['fedmsg'])
    expected_objects = set(['packages/fedmsg'])

    msg = {
        "i": 88,
        "timestamp": 1344447839.891876,
        "topic": "org.fedoraproject.prod.bodhi.update.eject",
        "msg": {
            "update": {
                "title": "fedmsg-0.2.7-2.el6",
                "submitter": {
                    "name": "ralph",
                },
                "status": "testing",
            },
            "reason": "some reason",
            "release": {
                "dist_tag": "el6",
                "locked": True,
                "long_name": "Fedora EPEL 6",
                "name": "EL6",
            },
            "request": "testing",
            "repo": "test_repo",
        }
    }


class TestBodhiUpdateComplete(Base):
    """ The `Bodhi Updates System <https://admin.fedoraproject.org/updates>`_
    publishes messages on this topic whenever an update
    **completes it's push to the testing repository**.  Here's a
    straightforward example:
    """
    expected_title = "bodhi.update.complete.testing"
    expected_subti = "ralph's fedmsg-0.2.7-2.el6 bodhi update " + \
        "completed push to testing"
    expected_link = "https://admin.fedoraproject.org/updates/" + \
        "fedmsg-0.2.7-2.el6"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c" + \
        "?s=64&d=retro"
    expected_usernames = set(['ralph'])
    expected_packages = set(['fedmsg'])
    expected_objects = set(['packages/fedmsg'])

    msg = {
        "i": 88,
        "timestamp": 1344447839.891876,
        "topic": "org.fedoraproject.prod.bodhi.update.complete.testing",
        "msg": {
            "update": {
                "title": "fedmsg-0.2.7-2.el6",
                "submitter": {
                    "name": "ralph",
                },
                "status": "testing",
            }
        }
    }


class TestBodhiRequestMultiplePackagesPerUpdate(Base):
    """ The `Bodhi Updates System <https://admin.fedoraproject.org/updates>`_
    publishes messages on this topic whenever a *user* requests that an update
    be pushed to the testing repository. Some updates may contain *multiple
    packages*, which can be a little tricky if you're not ready for it.  Here's
    an example of that:
    """
    expected_title = "bodhi.update.request.testing"
    expected_subti = "lmacken submitted " + \
        "gnome-settings-daemon-3.6.1-1.fc18,control-center-3.6.1-1.fc18" + \
        " to testing"
    expected_markup = (
        "<a href='https://admin.fedoraproject.org/updates/user/lmacken'>"
        "lmacken</a> submitted "
        "<a href='https://admin.fedoraproject.org/updates/"
        "gnome-settings-daemon-3.6.1-1.fc18,control-center-3.6.1-1.fc18'>"
        "gnome-settings-daemon-3.6.1-1.fc18,control-center-3.6.1-1.fc18</a>"
        " to testing")
    expected_link = "https://admin.fedoraproject.org/updates/" + \
        "gnome-settings-daemon-3.6.1-1.fc18,control-center-3.6.1-1.fc18"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "0d574577afa8deac19df2673cdea9aef45549ff8fac798ddaba61541c69e185a?s=64&d=retro"
    expected_usernames = set(['lmacken', 'hadess'])
    expected_packages = set(['gnome-settings-daemon', 'control-center'])
    expected_objects = set([
        'packages/gnome-settings-daemon',
        'packages/control-center',
    ])

    msg = {
        "topic": "org.fedoraproject.prod.bodhi.update.request.testing",
        "msg": {
            'agent': 'lmacken',
            "update": {
                "status": "pending",
                "critpath": False,
                "stable_karma": 3,
                "date_pushed": None,
                "title": "gnome-settings-daemon-3.6.1-1.fc18," +
                "control-center-3.6.1-1.fc18",
                "nagged": None,
                "comments": [
                    {
                        "group": None,
                        "author": "bodhi",
                        "text": "This update has been submitted for "
                        "testing by hadess. ",
                        "karma": 0,
                        "anonymous": False,
                        "timestamp": 1349718539.0,
                        "update_title": "gnome-settings-daemon-3.6.1-1.fc18," +
                        "control-center-3.6.1-1.fc18"
                    }
                ],
                "updateid": None,
                "type": "bugfix",
                "close_bugs": True,
                "date_submitted": 1349718534.0,
                "unstable_karma": -3,
                "release": {
                    "dist_tag": "f18",
                    "locked": True,
                    "long_name": "Fedora 18",
                    "name": "F18",
                    "id_prefix": "FEDORA"
                },
                "approved": None,
                "builds": [
                    {
                        "nvr": "gnome-settings-daemon-3.6.1-1.fc18",
                        "package": {
                            "suggest_reboot": False,
                            "committers": [
                                "hadess",
                                "ofourdan",
                                "mkasik",
                                "cosimoc"
                            ],
                            "name": "gnome-settings-daemon"
                        }
                    }, {
                        "nvr": "control-center-3.6.1-1.fc18",
                        "package": {
                            "suggest_reboot": False,
                            "committers": [
                                "ctrl-center-team",
                                "ofourdan",
                                "ssp",
                                "ajax",
                                "alexl",
                                "jrb",
                                "mbarnes",
                                "caolanm",
                                "davidz",
                                "mclasen",
                                "rhughes",
                                "hadess",
                                "johnp",
                                "caillon",
                                "whot",
                                "rstrode"
                            ],
                            "name": "control-center"
                        }
                    }
                ],
                "date_modified": None,
                "notes": "This update fixes numerous bugs in the new Input " +
                "Sources support, the Network panel and adds a help " +
                "screen accessible via Wacom tablets's buttons.",
                "request": "testing",
                "bugs": [],
                "critpath_approved": False,
                "karma": 0,
                "submitter": "hadess"
            }
        },
        "i": 2,
        "timestamp": 1349718539.0,
    }


class TestBodhiMashTaskMashing(Base):
    """ The `Bodhi Masher <https://admin.fedoraproject.org/updates>`_
    publishes messages on this topic whenever it starts mashing
    a particular repository.

    Note that, these messages are broken (serverside) due to `this
    issue <https://github.com/fedora-infra/fedmsg/issues/115>`_.
    """
    expected_title = "bodhi.mashtask.mashing"
    expected_subti = "bodhi masher started mashing test_repo"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = expected_icon
    expected_objects = set(['repos/test_repo'])

    msg = {
        'topic': "org.fedoraproject.prod.bodhi.mashtask.mashing",
        'msg': {
            'repo': 'test_repo',
            'updates': [
            ],
        },
    }


class TestBodhiMashTaskStart(Base):
    """ The `Bodhi Masher <https://admin.fedoraproject.org/updates>`_
    publishes messages on this topic whenever it **begins** its work.

    Note that, these messages are broken (serverside) due to `this
    issue <https://github.com/fedora-infra/fedmsg/issues/115>`_.
    """
    expected_title = "bodhi.mashtask.start"
    expected_subti = "bodhi masher started a push"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = expected_icon
    msg = {
        'topic': "org.fedoraproject.prod.bodhi.mashtask.start",
        'msg': {}
    }


class TestBodhiMashTaskComplete(Base):
    """ The `Bodhi Masher <https://admin.fedoraproject.org/updates>`_
    publishes messages on this topic whenever it **finishes** its work.

    Note that, these messages are broken (serverside) due to `this
    issue <https://github.com/fedora-infra/fedmsg/issues/115>`_.
    """
    expected_title = "bodhi.mashtask.complete"
    expected_subti = "bodhi masher failed to mash test_repo"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = expected_icon
    msg = {
        'topic': "org.fedoraproject.prod.bodhi.mashtask.complete",
        'msg': {'success': False, 'repo': 'test_repo'}
    }


class TestBodhiMashTaskSyncWaitStart(Base):
    """ The `Bodhi Masher <https://admin.fedoraproject.org/updates>`_
    publishes messages on this topic when it begins **waiting to sync**.

    Note that, these messages are broken (serverside) due to `this
    issue <https://github.com/fedora-infra/fedmsg/issues/115>`_.
    """
    expected_title = "bodhi.mashtask.sync.wait"
    expected_subti = "bodhi masher is waiting for test_repo " + \
        "to hit the master mirror"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = expected_icon
    msg = {
        'topic': "org.fedoraproject.prod.bodhi.mashtask.sync.wait",
        'msg': {'repo': 'test_repo'}
    }


class TestBodhiMashTaskSyncWaitDone(Base):
    """ The `Bodhi Masher <https://admin.fedoraproject.org/updates>`_
    publishes messages on this topic when it finishes syncing.

    Note that, these messages are broken (serverside) due to `this
    issue <https://github.com/fedora-infra/fedmsg/issues/115>`_.
    """
    expected_title = "bodhi.mashtask.sync.done"
    expected_subti = "bodhi masher finished waiting for test_repo " + \
        "to hit the master mirror"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = expected_icon

    msg = {
        'topic': "org.fedoraproject.prod.bodhi.mashtask.sync.done",
        'msg': {'repo': 'test_repo'}
    }


class TestBodhiRequestUnpush(Base):
    """ The `Bodhi Updates System <https://admin.fedoraproject.org/updates>`_
    publishes messages on this topic whenever a *user* requests that an update
    be **unpushed**.
    """
    expected_title = "bodhi.update.request.unpush"
    expected_subti = "lmacken unpushed foo"
    expected_markup = (
        "<a href='https://admin.fedoraproject.org/updates/user/lmacken'>"
        "lmacken</a> unpushed "
        "<a href='https://admin.fedoraproject.org/updates/"
        "foo'>foo</a>")
    expected_link = "https://admin.fedoraproject.org/updates/foo"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "203f6cb95b44b5d38aa21425b066dd522d3e19d8919cf4b339f29e0ea7f03e9b" + \
        "?s=64&d=retro"
    expected_usernames = set(['lmacken'])
    expected_packages = set(['foo'])
    expected_objects = set(['packages/foo'])

    msg = {
        'topic': "org.fedoraproject.dev.bodhi.update.request.unpush",
        'msg': {
            'agent': 'lmacken',
            'update': {
                'title': 'foo',
                'submitter': 'lmacken',
            },
        },
    }


class TestBodhiRequestObsolete(Base):
    """ The `Bodhi Updates System <https://admin.fedoraproject.org/updates>`_
    publishes messages on this topic whenever a *user* requests that an update
    be **obsoleted**.
    """
    expected_title = "bodhi.update.request.obsolete"
    expected_subti = "lmacken obsoleted foo"
    expected_markup = (
        "<a href='https://admin.fedoraproject.org/updates/user/lmacken'>"
        "lmacken</a> obsoleted "
        "<a href='https://admin.fedoraproject.org/updates/"
        "foo'>foo</a>")
    expected_link = "https://admin.fedoraproject.org/updates/foo"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "203f6cb95b44b5d38aa21425b066dd522d3e19d8919cf4b339f29e0ea7f03e9b?s=64&d=retro"
    expected_usernames = set(['lmacken'])
    expected_packages = set(['foo'])
    expected_objects = set(['packages/foo'])

    msg = {
        'topic': "org.fedoraproject.dev.bodhi.update.request.obsolete",
        'msg': {
            'agent': 'lmacken',
            'update': {
                'title': 'foo',
                'submitter': 'lmacken',
            },
        },
    }


class TestBodhiRequestStable(Base):
    """ The `Bodhi Updates System <https://admin.fedoraproject.org/updates>`_
    publishes messages on this topic whenever a *user* requests that an update
    be marked as **stable**.
    """
    expected_title = "bodhi.update.request.stable"
    expected_subti = "lmacken submitted foo to stable"
    expected_markup = (
        "<a href='https://admin.fedoraproject.org/updates/user/lmacken'>"
        "lmacken</a> submitted "
        "<a href='https://admin.fedoraproject.org/updates/"
        "foo'>foo</a> to stable")
    expected_link = "https://admin.fedoraproject.org/updates/foo"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "203f6cb95b44b5d38aa21425b066dd522d3e19d8919cf4b339f29e0ea7f03e9b?s=64&d=retro"
    expected_usernames = set(['lmacken'])
    expected_packages = set(['foo'])
    expected_objects = set(['packages/foo'])

    msg = {
        'topic': "org.fedoraproject.dev.bodhi.update.request.stable",
        'msg': {
            'agent': 'lmacken',
            'update': {
                'title': 'foo',
                'submitter': 'lmacken',
            },
        },
    }


class TestBodhiRequestRevoke(Base):
    """ The `Bodhi Updates System <https://admin.fedoraproject.org/updates>`_
    publishes messages on this topic whenever a *user* revokes a prior
    request on an update.
    """
    expected_title = "bodhi.update.request.revoke"
    expected_subti = "lmacken revoked foo"
    expected_markup = (
        "<a href='https://admin.fedoraproject.org/updates/user/lmacken'>"
        "lmacken</a> revoked "
        "<a href='https://admin.fedoraproject.org/updates/"
        "foo'>foo</a>")
    expected_link = "https://admin.fedoraproject.org/updates/foo"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "203f6cb95b44b5d38aa21425b066dd522d3e19d8919cf4b339f29e0ea7f03e9b?s=64&d=retro"
    expected_usernames = set(['lmacken'])
    expected_packages = set(['foo'])
    expected_objects = set(['packages/foo'])

    msg = {
        'topic': "org.fedoraproject.dev.bodhi.update.request.revoke",
        'msg': {
            'agent': 'lmacken',
            'update': {
                'title': 'foo',
                'submitter': 'lmacken',
            },
        },
    }


class TestBodhiRequestTesting(Base):
    """ The `Bodhi Updates System <https://admin.fedoraproject.org/updates>`_
    publishes messages on this topic whenever a *user* requests that an
    update be pushed to the testing repository.
    """
    expected_title = "bodhi.update.request.testing"
    expected_subti = "lmacken submitted foo to testing"
    expected_markup = (
        "<a href='https://admin.fedoraproject.org/updates/user/lmacken'>"
        "lmacken</a> submitted "
        "<a href='https://admin.fedoraproject.org/updates/"
        "foo'>foo</a> to testing")
    expected_link = "https://admin.fedoraproject.org/updates/foo"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "203f6cb95b44b5d38aa21425b066dd522d3e19d8919cf4b339f29e0ea7f03e9b?s=64&d=retro"
    expected_usernames = set(['lmacken'])
    expected_packages = set(['foo'])
    expected_objects = set(['packages/foo'])

    msg = {
        'topic': "org.fedoraproject.dev.bodhi.update.request.testing",
        'msg': {
            'agent': 'lmacken',
            'update': {
                'title': 'foo',
                'submitter': 'lmacken',
            },
        },
    }


class TestBodhiComment(Base):
    """ The `Bodhi Updates System <https://admin.fedoraproject.org/updates>`_
    publishes messages on this topic whenever a user **comments** on a bodhi
    update.
    """
    expected_title = "bodhi.update.comment"
    expected_subti = "ralph commented on bodhi update fedmsg-1.0-1 (karma: -1)"
    expected_long_form = "Can you believe how much testing we're doing? " + \
        "/cc @codeblock."
    expected_markup = (
        "<a href='https://admin.fedoraproject.org/updates/user/ralph'>"
        "ralph</a> commented on bodhi update "
        "<a href='https://admin.fedoraproject.org/updates/"
        "fedmsg-1.0-1'>fedmsg-1.0-1</a> (karma: -1)")
    expected_link = "https://admin.fedoraproject.org/updates/fedmsg-1.0-1"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro"
    expected_usernames = set(['ralph', 'codeblock'])
    expected_packages = set(['fedmsg'])
    expected_objects = set(['packages/fedmsg'])

    msg = {
        "i": 1,
        "timestamp": 1344344053.2337201,
        "topic": "org.fedoraproject.stg.bodhi.update.comment",
        "msg": {
            "comment": {
                "update_title": "fedmsg-1.0-1",
                "group": None,
                "author": "ralph",
                "text": "Can you believe how much testing we're doing?"
                " /cc @codeblock.",
                "karma": -1,
                "anonymous": False,
                "timestamp": 1344344050.0
            }
        }
    }


class TestBodhiOverrideTagged(Base):
    """ The `Bodhi Updates System <https://admin.fedoraproject.org/updates>`_
    publishes messages on this topic whenever a user **requests a buildroot
    override** for an update.
    """
    expected_title = "bodhi.buildroot_override.tag"
    expected_subti = "lmacken submitted a buildroot override for fedmsg-1.0-1"
    expected_markup = (
        "<a href='https://admin.fedoraproject.org/updates/user/lmacken'>"
        "lmacken</a> submitted a buildroot override for fedmsg-1.0-1")
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "203f6cb95b44b5d38aa21425b066dd522d3e19d8919cf4b339f29e0ea7f03e9b?s=64&d=retro"
    expected_usernames = set(['lmacken'])
    expected_packages = set(['fedmsg'])
    expected_objects = set(['packages/fedmsg'])

    msg = {
        "i": 1,
        "timestamp": 1344344053.2337201,
        "topic": "org.fedoraproject.stg.bodhi.buildroot_override.tag",
        "msg": {
            "override": {
                "build": {
                    "nvr": "fedmsg-1.0-1",
                    "override": 1,
                },
                "submitter": {
                    "name": "lmacken",
                },
            }
        }
    }


class LegacyTestBodhiOverrideTagged(Base):
    """ The `Bodhi Updates System <https://admin.fedoraproject.org/updates>`_
    publishes messages on this topic whenever a user **requests a buildroot
    override** for an update.
    """
    expected_title = "bodhi.buildroot_override.tag"
    expected_subti = "lmacken submitted a buildroot override for fedmsg-1.0-1"
    expected_markup = (
        "<a href='https://admin.fedoraproject.org/updates/user/lmacken'>"
        "lmacken</a> submitted a buildroot override for fedmsg-1.0-1")
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "203f6cb95b44b5d38aa21425b066dd522d3e19d8919cf4b339f29e0ea7f03e9b?s=64&d=retro"
    expected_usernames = set(['lmacken'])
    expected_packages = set(['fedmsg'])
    expected_objects = set(['packages/fedmsg'])

    msg = {
        "i": 1,
        "timestamp": 1344344053.2337201,
        "topic": "org.fedoraproject.stg.bodhi.buildroot_override.tag",
        "msg": {
            "override": {
                "build": "fedmsg-1.0-1",
                "submitter": "lmacken",
            }
        }
    }


class TestBodhiOverrideUntagged(Base):
    """ The `Bodhi Updates System <https://admin.fedoraproject.org/updates>`_
    publishes messages on this topic whenever a user explicitly removes a
    previously requested buildroot override.
    """
    expected_title = "bodhi.buildroot_override.untag"
    expected_subti = "lmacken expired a buildroot override for fedmsg-1.0-1"
    expected_markup = (
        "<a href='https://admin.fedoraproject.org/updates/user/lmacken'>"
        "lmacken</a> expired a buildroot override for fedmsg-1.0-1")
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "203f6cb95b44b5d38aa21425b066dd522d3e19d8919cf4b339f29e0ea7f03e9b?s=64&d=retro"
    expected_usernames = set(['lmacken'])
    expected_packages = set(['fedmsg'])
    expected_objects = set(['packages/fedmsg'])

    msg = {
        "i": 1,
        "timestamp": 1344964395.207541,
        "topic": "org.fedoraproject.stg.bodhi.buildroot_override.untag",
        "msg": {
            "override": {
                "build": {
                    "nvr": "fedmsg-1.0-1",
                    "override": 1,
                },
                "submitter": {
                    "name": "lmacken",
                },
            }
        }
    }



class LegacyTestBodhiOverrideUntagged(Base):
    """ The `Bodhi Updates System <https://admin.fedoraproject.org/updates>`_
    publishes messages on this topic whenever a user explicitly removes a
    previously requested buildroot override.
    """
    expected_title = "bodhi.buildroot_override.untag"
    expected_subti = "lmacken expired a buildroot override for fedmsg-1.0-1"
    expected_markup = (
        "<a href='https://admin.fedoraproject.org/updates/user/lmacken'>"
        "lmacken</a> expired a buildroot override for fedmsg-1.0-1")
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "203f6cb95b44b5d38aa21425b066dd522d3e19d8919cf4b339f29e0ea7f03e9b?s=64&d=retro"
    expected_usernames = set(['lmacken'])
    expected_packages = set(['fedmsg'])
    expected_objects = set(['packages/fedmsg'])

    msg = {
        "i": 1,
        "timestamp": 1344964395.207541,
        "topic": "org.fedoraproject.stg.bodhi.buildroot_override.untag",
        "msg": {
            "override": {
                "build": "fedmsg-1.0-1",
                "submitter": "lmacken",
            }
        }
    }


class TestBodhiStackSave(Base):
    """ `Bodhi2 <https://admin.fedoraproject.org/updates>`_ introduced the
    concept of *stacks* of packages that can be grouped for to share
    requirements.  That system publishes messages like this anytime a user
    **modifies or creates a new stack**.
    """
    expected_title = "bodhi.stack.save"
    expected_subti = "ralph updated the \"hacking\" stack"
    expected_link = "https://admin.fedoraproject.org/updates/stacks/hacking"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c" + \
        "?s=64&d=retro"
    expected_usernames = set(['ralph'])
    expected_packages = set(['nethack'])
    expected_objects = set(['packages/nethack', 'stacks/hacking'])

    msg = {
        "username": "threebean",
        "i": 2,
        "timestamp": 1422302779,
        "msg_id": "2015-21b9ae33-3fdf-42ab-aecb-5717d0d76018",
        "topic": "org.fedoraproject.dev.bodhi.stack.save",
        "msg": {
            "stack": {
                "requirements": "depcheck upgradepath",
                "description": "the greatest game you will ever play",
                "name": "hacking",
                "groups": [],
                "packages": [
                    {
                        "committers": [],
                        "requirements": "depcheck upgradepath",
                        "builds": [],
                        "stack_id": 9,
                        "test_cases": [],
                        "stack": 9,
                        "name": "nethack"
                    }
                ],
                "users": [
                    {
                        "buildroot_overrides": [],
                        "stacks": [
                            1,
                            8,
                            9
                        ],
                        "name": "ralph",
                        "avatar": None
                    }
                ]
            },
            "agent": "ralph"
        }
    }


class TestBodhiStackDelete(Base):
    """ `Bodhi2 <https://admin.fedoraproject.org/updates>`_ introduced the
    concept of *stacks* of packages that can be grouped for to share
    requirements.  That system publishes messages like this anytime a user
    **deletes a stack**.
    """
    expected_title = "bodhi.stack.delete"
    expected_subti = "ralph deleted the \"hacking\" stack"
    expected_link = "https://admin.fedoraproject.org/updates/stacks/hacking"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c" + \
        "?s=64&d=retro"
    expected_usernames = set(['ralph'])
    expected_packages = set(['nethack'])
    expected_objects = set(['packages/nethack', 'stacks/hacking'])

    msg = {
        "username": "threebean",
        "i": 2,
        "timestamp": 1422302779,
        "msg_id": "2015-21b9ae33-3fdf-42ab-aecb-5717d0d76018",
        "topic": "org.fedoraproject.dev.bodhi.stack.delete",
        "msg": {
            "stack": {
                "requirements": "depcheck upgradepath",
                "description": "the greatest game you will ever play",
                "name": "hacking",
                "groups": [],
                "packages": [
                    {
                        "committers": [],
                        "requirements": "depcheck upgradepath",
                        "builds": [],
                        "stack_id": 9,
                        "test_cases": [],
                        "stack": 9,
                        "name": "nethack"
                    }
                ],
                "users": [
                    {
                        "buildroot_overrides": [],
                        "stacks": [
                            1,
                            8,
                            9
                        ],
                        "name": "ralph",
                        "avatar": None
                    }
                ]
            },
            "agent": "ralph"
        }
    }


class TestBodhiUpdateEdit(Base):
    """ `Bodhi2 <https://admin.fedoraproject.org/updates>`_ publishes
    this kind of message when a package maintainer **edits a pre-existing
    update**.
    """
    expected_title = "bodhi.update.edit"
    expected_subti = "ralph edited tzdata-2014i-1.fc19"
    expected_link = "https://admin.fedoraproject.org/updates/" + \
        "tzdata-2014i-1.fc19"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c" + \
        "?s=64&d=retro"
    expected_usernames = set(['ralph'])
    expected_packages = set(['tzdata'])
    expected_objects = set(['packages/tzdata'])
    msg = {
        "username": "apache",
        "timestamp": 1422414175,
        "msg_id": "2015-2b398e44-8012-455f-bfeb-195b9dda18f6",
        "topic": "org.fedoraproject.dev.bodhi.update.edit",
        "msg": {
            "update": {
                "close_bugs": True,
                "old_updateid": None,
                "pushed": False,
                "require_testcases": True,
                "critpath": False,
                "cves": [],
                "stable_karma": 3,
                "date_pushed": None,
                "requirements": "rpmlint",
                "severity": "unspecified",
                "title": "tzdata-2014i-1.fc19",
                "suggest": "unspecified",
                "require_bugs": True,
                "comments": [
                    {
                        "bug_feedback": [],
                        "user_id": 1681,
                        "timestamp": "2015-01-28 03:02:44",
                        "testcase_feedback": [],
                        "karma_critpath": 0,
                        "update": 54046,
                        "update_id": 54046,
                        "karma": 0,
                        "anonymous": False,
                        "text": "ralph edited this update. ",
                        "id": 484236,
                        "user": {
                            "buildroot_overrides": [],
                            "stacks": [],
                            "name": "bodhi",
                            "avatar": None
                        }
                    }
                ],
                "date_approved": None,
                "type": "enhancement",
                "status": "pending",
                "date_submitted": "2014-10-29 20:02:57",
                "unstable_karma": -3,
                "user": {
                    "buildroot_overrides": [],
                    "stacks": [
                        {
                            "requirements": "depcheck upgradepath",
                            "description": "This stack is so hack!",
                            "name": "Hackey",
                            "groups": [],
                            "packages": [],
                            "users": [
                                1711
                            ]
                        },
                    ],
                    "name": "ralph",
                    "avatar": None
                },
                "locked": False,
                "builds": [
                    {
                        "override": None,
                        "nvr": "tzdata-2014i-1.fc19"
                    }
                ],
                "date_modified": "2015-01-28 03:02:55",
                "notes": "the update notes go here...",
                "request": "testing",
                "bugs": [],
                "alias": None,
                "karma": 0,
                "release": {
                    "dist_tag": "f19",
                    "name": "F19",
                    "testing_tag": "f19-updates-testing",
                    "pending_stable_tag": "f19-updates-pending",
                    "long_name": "Fedora 19",
                    "state": "disabled",
                    "version": None,
                    "override_tag": "f19-override",
                    "branch": None,
                    "id_prefix": "FEDORA",
                    "pending_testing_tag": "f19-updates-testing-pending",
                    "stable_tag": "f19-updates",
                    "candidate_tag": "f19-updates-candidate"
                }
            },
            "agent": "ralph"
        }
    }


class TestBodhiKarmaThresholdStable(Base):
    """ `Bodhi2 <https://admin.fedoraproject.org/updates>`_ publishes these
    messages when an update reaches the stable or unstable karma thresholds.
    """
    expected_title = "bodhi.update.karma.threshold"
    expected_subti = "tzdata-2014i-1.fc19 reached the stable karma threshold"
    expected_link = "https://admin.fedoraproject.org/updates/" + \
        "FEDORA-EPEL-2015-0238"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/tzdata.png"
    expected_usernames = set([])
    expected_packages = set(['tzdata'])
    expected_objects = set(['packages/tzdata'])
    msg = {
        "username": "threebean",
        "i": 2,
        "timestamp": 1422302779,
        "msg_id": "2015-21b9ae33-3fdf-42ab-aecb-5717d0d76018",
        "topic": "org.fedoraproject.dev.bodhi.update.karma.threshold",
        "msg": {
            "status": "stable",
            "update": {
                "close_bugs": True,
                "old_updateid": None,
                "pushed": False,
                "require_testcases": True,
                "critpath": False,
                "cves": [],
                "stable_karma": 3,
                "date_pushed": None,
                "requirements": "rpmlint",
                "severity": "unspecified",
                "title": "tzdata-2014i-1.fc19",
                "suggest": "unspecified",
                "require_bugs": True,
                "comments": [
                    {
                        "bug_feedback": [],
                        "user_id": 1681,
                        "timestamp": "2015-01-28 03:02:44",
                        "testcase_feedback": [],
                        "karma_critpath": 0,
                        "update": 54046,
                        "update_id": 54046,
                        "karma": 0,
                        "anonymous": False,
                        "text": "ralph edited this update. ",
                        "id": 484236,
                        "user": {
                            "buildroot_overrides": [],
                            "stacks": [],
                            "name": "bodhi",
                            "avatar": None
                        }
                    }
                ],
                "date_approved": None,
                "type": "enhancement",
                "status": "pending",
                "date_submitted": "2014-10-29 20:02:57",
                "unstable_karma": -3,
                "user": {
                    "buildroot_overrides": [],
                    "stacks": [
                        {
                            "requirements": "depcheck upgradepath",
                            "description": "This stack is so hack!",
                            "name": "Hackey",
                            "groups": [],
                            "packages": [],
                            "users": [
                                1711
                            ]
                        },
                    ],
                    "name": "ralph",
                    "avatar": None
                },
                "locked": False,
                "builds": [
                    {
                        "override": None,
                        "nvr": "tzdata-2014i-1.fc19"
                    }
                ],
                "date_modified": "2015-01-28 03:02:55",
                "notes": "the update notes go here...",
                "request": "testing",
                "bugs": [],
                "alias": "FEDORA-EPEL-2015-0238",
                "karma": 0,
                "release": {
                    "dist_tag": "f19",
                    "name": "F19",
                    "testing_tag": "f19-updates-testing",
                    "pending_stable_tag": "f19-updates-pending",
                    "long_name": "Fedora 19",
                    "state": "disabled",
                    "version": None,
                    "override_tag": "f19-override",
                    "branch": None,
                    "id_prefix": "FEDORA",
                    "pending_testing_tag": "f19-updates-testing-pending",
                    "stable_tag": "f19-updates",
                    "candidate_tag": "f19-updates-candidate"
                }
            },
        }
    }


class TestBodhiErrataPublish(Base):
    """ `Bodhi2 <https://admin.fedoraproject.org/updates>`_, along with many
    other services, moved away from sending its own email notifications to
    instead publish fedmsg messages that the `FMN system
    <https://apps.fedoraproject.org/notifications>`_ would be responsible for
    forwarding.

    This message type comes from that move.  It represents the "errata" for a
    package when it it mashed into a repository.
    """
    expected_title = "bodhi.errata.publish"
    expected_subti = "This is the subject of the errata email"
    expected_long_form = "This is the body of the errata email"
    expected_link = "https://admin.fedoraproject.org/updates/" + \
        "tzdata-2014i-1.fc19"
    expected_icon = "https://admin.fedoraproject.org/updates" + \
        "/static/images/bodhi-icon-48.png"
    expected_secondary_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/tzdata.png"
    expected_usernames = set([])
    expected_packages = set(['tzdata'])
    expected_objects = set(['packages/tzdata'])
    msg = {
        "username": "threebean",
        "i": 2,
        "timestamp": 1422302779,
        "msg_id": "2015-21b9ae33-3fdf-42ab-aecb-5717d0d76018",
        "topic": "org.fedoraproject.dev.bodhi.errata.publish",
        "msg": {
            "subject": "This is the subject of the errata email",
            "body": "This is the body of the errata email",
            "update": {
                "close_bugs": True,
                "old_updateid": None,
                "pushed": False,
                "require_testcases": True,
                "critpath": False,
                "cves": [],
                "stable_karma": 3,
                "date_pushed": None,
                "requirements": "rpmlint",
                "severity": "unspecified",
                "title": "tzdata-2014i-1.fc19",
                "suggest": "unspecified",
                "require_bugs": True,
                "comments": [
                    {
                        "bug_feedback": [],
                        "user_id": 1681,
                        "timestamp": "2015-01-28 03:02:44",
                        "testcase_feedback": [],
                        "karma_critpath": 0,
                        "update": 54046,
                        "update_id": 54046,
                        "karma": 0,
                        "anonymous": False,
                        "text": "ralph edited this update. ",
                        "id": 484236,
                        "user": {
                            "buildroot_overrides": [],
                            "stacks": [],
                            "name": "bodhi",
                            "avatar": None
                        }
                    }
                ],
                "date_approved": None,
                "type": "enhancement",
                "status": "pending",
                "date_submitted": "2014-10-29 20:02:57",
                "unstable_karma": -3,
                "user": {
                    "buildroot_overrides": [],
                    "stacks": [
                        {
                            "requirements": "depcheck upgradepath",
                            "description": "This stack is so hack!",
                            "name": "Hackey",
                            "groups": [],
                            "packages": [],
                            "users": [
                                1711
                            ]
                        },
                    ],
                    "name": "ralph",
                    "avatar": None
                },
                "locked": False,
                "builds": [
                    {
                        "override": None,
                        "nvr": "tzdata-2014i-1.fc19"
                    }
                ],
                "date_modified": "2015-01-28 03:02:55",
                "notes": "the update notes go here...",
                "request": "testing",
                "bugs": [],
                "alias": None,
                "karma": 0,
                "release": {
                    "dist_tag": "f19",
                    "name": "F19",
                    "testing_tag": "f19-updates-testing",
                    "pending_stable_tag": "f19-updates-pending",
                    "long_name": "Fedora 19",
                    "state": "disabled",
                    "version": None,
                    "override_tag": "f19-override",
                    "branch": None,
                    "id_prefix": "FEDORA",
                    "pending_testing_tag": "f19-updates-testing-pending",
                    "stable_tag": "f19-updates",
                    "candidate_tag": "f19-updates-candidate"
                }
            },
        }
    }


add_doc(locals())

if __name__ == '__main__':
    unittest.main()



# This file is part of fedmsg.
# Copyright (C) 2015 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Pierre-Yves Chibon <pingou@pingoured.fr>
#
""" Tests for anitya messages """

import unittest

from fedmsg_meta_fedora_infrastructure.tests.base import Base

from .common import add_doc


class TestNewProject(Base):
    """ These messages are published when a new project is created on
    `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.project.new"
    expected_subti = 'pingou created a new project "foo"'
    expected_link = "https://pagure.io/foo"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/foo'])
    msg = {
      "i": 1,
      "timestamp": 1427445138,
      "msg_id": "2015-a37b0f13-aead-40eb-ab53-7af8e89e6854",
      "topic": "io.pagure.dev.pagure.project.new",
      "msg": {
        "project": {
          "description": "bar",
          "parent": None,
          "project_docs": True,
          "issue_tracker": True,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          },
          "date_created": "1427441537",
          "id": 7,
          "name": "foo"
        },
        "agent": "pingou"
      }
    }


class TestNewIssue(Base):
    """ These messages are published when a ticket is opened against a
    project on `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.issue.new"
    expected_subti = 'pingou opened a new ticket foo#4: "bug"'
    expected_link = "https://pagure.io/foo/issue/4"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/foo', 'issue/4'])
    msg = {
      "i": 2,
      "timestamp": 1427445817,
      "msg_id": "2015-a9e8a8d6-6197-48b8-9fc9-a03967a9d4bb",
      "topic": "io.pagure.dev.pagure.issue.new",
      "msg": {
        "project": {
          "description": "bar",
          "parent": None,
          "project_docs": True,
          "issue_tracker": True,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          },
          "date_created": "1427441537",
          "id": 7,
          "name": "foo"
        },
        "issue": {
          "status": "Open",
          "blocks": "",
          "title": "bug",
          "tags": [],
          "comments": [],
          "content": "report",
          "depends": "",
          "private": False,
          "date_created": "1427442217",
          "id": 4,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          }
        },
        "agent": "pingou"
      }
    }


class TestNewIssueComment(Base):
    """ These messages are published when a someone comments on a ticket
    opened against a project on `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.issue.comment.added"
    expected_subti = 'pingou commented on the ticket foo#4: "bug"'
    expected_link = "https://pagure.io/foo/issue/4"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/foo', 'issue/4'])
    msg = {
      "i": 1,
      "timestamp": 1427448698,
      "msg_id": "2015-539fc955-db5a-4bb5-a6a6-4a096a2d795d",
      "topic": "io.pagure.dev.pagure.issue.comment.added",
      "msg": {
        "project": {
          "description": "bar",
          "parent": None,
          "project_docs": True,
          "issue_tracker": True,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          },
          "date_created": "1427441537",
          "id": 7,
          "name": "foo"
        },
        "issue": {
          "status": "Open",
          "blocks": "",
          "title": "bug",
          "tags": [],
          "comments": [
            {
              "comment": "We should really fix this",
              "date_created": "1427445097",
              "id": 380,
              "parent": None,
              "user": {
                "fullname": "Pierre-YvesChibon",
                "emails": [
                  "pingou@fedoraproject.org"
                ],
                "name": "pingou"
              }
            }
          ],
          "content": "report",
          "depends": "",
          "private": False,
          "date_created": "1427442217",
          "id": 4,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          }
        },
        "agent": "pingou"
      }
    }


class TestNewIssueTag(Base):
    """ These messages are published when a someone adds a tag on a ticket
    opened against a project on `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.issue.tag.added"
    expected_subti = 'pingou tagged the ticket foo#4: easyfix, bug'
    expected_link = "https://pagure.io/foo/issue/4"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/foo', 'issue/4'])
    msg = {
      "i": 4,
      "timestamp": 1427449624,
      "msg_id": "2015-64ac444e-915c-4a6c-820b-59e8daf14584",
      "topic": "io.pagure.dev.pagure.issue.tag.added",
      "msg": {
        "project": {
          "description": "bar",
          "parent": None,
          "project_docs": True,
          "issue_tracker": True,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          },
          "date_created": "1427441537",
          "id": 7,
          "name": "foo"
        },
        "tags": [
          "easyfix",
          "bug",
        ],
        "issue": {
          "status": "Open",
          "blocks": "",
          "title": "bug",
          "tags": [],
          "comments": [],
          "content": "report",
          "depends": "",
          "private": False,
          "date_created": "1427442217",
          "id": 4,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          }
        },
        "agent": "pingou"
      }
    }


class TestRemovedIssueTag(Base):
    """ These messages are published when a someone removes a tag on a
    ticket opened against a project on `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.issue.tag.removed"
    expected_subti = 'pingou removed tags: feature, future, from the '\
        'ticket foo#4'
    expected_link = "https://pagure.io/foo/issue/4"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/foo', 'issue/4'])
    msg = {
      "i": 4,
      "timestamp": 1427450043,
      "msg_id": "2015-e1921852-c269-4c08-a611-dffe5c39417f",
      "topic": "io.pagure.dev.pagure.issue.tag.removed",
      "msg": {
        "project": {
          "description": "bar",
          "parent": None,
          "project_docs": True,
          "issue_tracker": True,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          },
          "date_created": "1427441537",
          "id": 7,
          "name": "foo"
        },
        "issue": {
          "status": "Open",
          "blocks": "",
          "title": "bug",
          "tags": "",
          "comments": [],
          "content": "report",
          "depends": "",
          "private": False,
          "date_created": "1427442217",
          "id": 4,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          }
        },
        "agent": "pingou",
        "tags": [
          "feature",
          "future"
        ]
      }
    }


class TestAssignedIssue(Base):
    """ These messages are published when a someone is assigned to a
    ticket opened against a project on `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.issue.assigned.added"
    expected_subti = 'pingou assigned ralph to the ticket foo#4'
    expected_link = "https://pagure.io/foo/issue/4"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/foo', 'issue/4'])
    msg = {
      "i": 3,
      "timestamp": 1427450780,
      "msg_id": "2015-4ab5479a-1a99-4e26-a52f-e9e1ce423e40",
      "topic": "io.pagure.dev.pagure.issue.assigned.added",
      "msg": {
        "project": {
          "description": "bar",
          "parent": None,
          "project_docs": True,
          "issue_tracker": True,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          },
          "date_created": "1427441537",
          "id": 7,
          "name": "foo"
        },
        "issue": {
          "status": "Open",
          "blocks": "",
          "title": "bug",
          "tags": [],
          "comments": [],
          "content": "report",
          "assignee": {
            "fullname": "Ralph",
            "emails": [
              "ralph@fedoraproject.org"
            ],
            "name": "ralph"
          },
          "depends": "",
          "private": False,
          "date_created": "1427442217",
          "id": 4,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          }
        },
        "agent": "pingou"
      }
    }


class TestResetAssignedIssue(Base):
    """ These messages are published when a someone is reset the assignee
    of a ticket opened against a project on `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.issue.assigned.reset"
    expected_subti = 'pingou reset the assignee of the ticket foo#4'
    expected_link = "https://pagure.io/foo/issue/4"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/foo', 'issue/4'])
    msg = {
      "i": 3,
      "timestamp": 1427453148,
      "msg_id": "2015-bc20fa0e-8baa-4b6a-ac44-c30b9e579da3",
      "topic": "io.pagure.dev.pagure.issue.assigned.reset",
      "msg": {
        "project": {
          "description": "bar",
          "parent": None,
          "project_docs": True,
          "issue_tracker": True,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          },
          "date_created": "1427441537",
          "id": 7,
          "name": "foo"
        },
        "issue": {
          "status": "Open",
          "blocks": "",
          "title": "bug",
          "tags": [],
          "comments": [],
          "content": "report",
          "assignee": None,
          "depends": "",
          "private": False,
          "date_created": "1427442217",
          "id": 4,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          }
        },
        "agent": "pingou"
      }
    }


class TestNewIssueDependency(Base):
    """ These messages are published when a someone is reset the assignee
    of a ticket opened against a project on `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.issue.dependency.added"
    expected_subti = 'pingou added on the ticket foo#2 a dependency on '\
    'ticket foo#4'
    expected_link = "https://pagure.io/foo/issue/2"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/foo', 'issue/2'])
    msg = {
      "i": 2,
      "timestamp": 1427453868,
      "msg_id": "2015-c8189e0c-ef22-4e72-92cc-9ffa68c35b7b",
      "topic": "io.pagure.dev.pagure.issue.dependency.added",
      "msg": {
        "project": {
          "description": "bar",
          "parent": None,
          "project_docs": True,
          "issue_tracker": True,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          },
          "date_created": "1427441537",
          "id": 7,
          "name": "foo"
        },
        "issue": {
          "status": "Open",
          "blocks": [4],
          "title": "bug",
          "tags": [],
          "comments": [],
          "content": "report",
          "assignee": None,
          "depends": "",
          "private": False,
          "date_created": "1427442076",
          "id": 2,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          }
        },
        "added_dependency": 4,
        "agent": "pingou"
      }
    }


class TestRemovedIssueDependency(Base):
    """ These messages are published when a someone is reset the assignee
    of a ticket opened against a project on `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.issue.dependency.removed"
    expected_subti = 'pingou removed on the ticket foo#4 the dependency on '\
    'ticket foo#2'
    expected_link = "https://pagure.io/foo/issue/4"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/foo', 'issue/4'])
    msg = {
      "i": 3,
      "timestamp": 1427454576,
      "msg_id": "2015-cb2e1acd-c6c7-4da4-ba99-c136954bb039",
      "topic": "io.pagure.dev.pagure.issue.dependency.removed",
      "msg": {
        "project": {
          "description": "bar",
          "parent": None,
          "project_docs": True,
          "issue_tracker": True,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          },
          "date_created": "1427441537",
          "id": 7,
          "name": "foo"
        },
        "removed_dependency": 2,
        "issue": {
          "status": "Open",
          "blocks": [],
          "title": "bug",
          "tags": [
            "0.1"
          ],
          "comments": [],
          "content": "report",
          "assignee": None,
          "depends": [],
          "private": False,
          "date_created": "1427442217",
          "id": 4,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          }
        },
        "agent": "pingou"
      }
    }


class TestIssueEdit(Base):
    """ These messages are published when a someone edited a ticket opened
    against a project on `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.issue.edit"
    expected_subti = 'pingou edited the fields: "status", "private" of the '\
        'ticket foo#4'
    expected_link = "https://pagure.io/foo/issue/4"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/foo', 'issue/4'])
    msg = {
      "i": 5,
      "timestamp": 1427454847,
      "msg_id": "2015-5755ee3a-43ba-4552-9423-8fe3b0a96662",
      "topic": "io.pagure.dev.pagure.issue.edit",
      "msg": {
        "fields": [
          "status",
          "private"
        ],
        "project": {
          "description": "bar",
          "parent": None,
          "project_docs": True,
          "issue_tracker": True,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          },
          "date_created": "1427441537",
          "id": 7,
          "name": "foo"
        },
        "issue": {
          "status": "Fixed",
          "blocks": [],
          "title": "bug",
          "tags": [
            "0.1"
          ],
          "comments": [],
          "content": "report",
          "assignee": None,
          "depends": [],
          "private": False,
          "date_created": "1427442217",
          "id": 4,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          }
        },
        "agent": "pingou"
      }
    }


class TestProjectEdit(Base):
    """ These messages are published when a someone edited a project on
    `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.project.edit"
    expected_subti = 'pingou edited the fields: "project_docs" of the '\
        'project foo'
    expected_link = "https://pagure.io/foo"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/foo'])
    msg = {
      "i": 2,
      "timestamp": 1427455343,
      "msg_id": "2015-3b53c72a-8585-4ddc-ba60-d7e969a0acbb",
      "topic": "io.pagure.dev.pagure.project.edit",
      "msg": {
        "project": {
          "description": "bar",
          "parent": None,
          "project_docs": False,
          "issue_tracker": True,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          },
          "date_created": "1427441537",
          "id": 7,
          "name": "foo"
        },
        "fields": [
          "project_docs"
        ],
        "agent": "pingou"
      }
    }


class TestProjectUserAdded(Base):
    """ These messages are published when a someone gave admins rights on a
    project on `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.project.user.added"
    expected_subti = 'pingou added "ralph" to the project foo'
    expected_link = "https://pagure.io/foo"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/foo'])
    msg = {
      "i": 4,
      "timestamp": 1427455518,
      "msg_id": "2015-b3c2e568-259a-4b1f-9ecc-79493b89687a",
      "topic": "io.pagure.dev.pagure.project.user.added",
      "msg": {
        "new_user": "ralph",
        "project": {
          "description": "bar",
          "parent": None,
          "project_docs": False,
          "issue_tracker": True,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          },
          "date_created": "1427441537",
          "id": 7,
          "name": "foo"
        },
        "agent": "pingou"
      }
    }


class TestProjectTagRemoved(Base):
    """ These messages are published when a someone removed a tag of a
    project on `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.project.tag.removed"
    expected_subti = 'pingou removed tags "easyfix1" of the project foo'
    expected_link = "https://pagure.io/foo"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/foo'])
    msg = {
      "i": 5,
      "timestamp": 1427455744,
      "msg_id": "2015-c6db4dd3-0a87-4eee-aab7-7758f566f36e",
      "topic": "io.pagure.dev.pagure.project.tag.removed",
      "msg": {
        "project": {
          "description": "bar",
          "parent": None,
          "project_docs": False,
          "issue_tracker": True,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          },
          "date_created": "1427441537",
          "id": 7,
          "name": "foo"
        },
        "agent": "pingou",
        "tags": [
          "easyfix1"
        ]
      }
    }


class TestProjectTagEdited(Base):
    """ These messages are published when a someone edited a tag of a
    project on `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.project.tag.edited"
    expected_subti = 'pingou edited tags "easyfix1" of the project foo '\
        'to "easyfix"'
    expected_link = "https://pagure.io/foo"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/foo'])
    msg = {
      "i": 2,
      "timestamp": 1427456487,
      "msg_id": "2015-79d76ac7-5c66-460d-8a39-17849e462a85",
      "topic": "io.pagure.dev.pagure.project.tag.edited",
      "msg": {
        "project": {
          "description": "bar",
          "parent": None,
          "project_docs": False,
          "issue_tracker": True,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          },
          "date_created": "1427441537",
          "id": 7,
          "name": "foo"
        },
        "new_tag": "easyfix",
        "old_tag": "easyfix1",
        "agent": "pingou"
      }
    }


class TestProjectForked(Base):
    """ These messages are published when a someone edited a tag of a
    project on `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.project.forked"
    expected_subti = 'pingou forked project "fedmsg" to "pingou/fedmsg"'
    expected_link = "https://pagure.io/fork/pingou/fedmsg"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/pingou/fedmsg'])
    msg = {
      "i": 3,
      "timestamp": 1427456769,
      "msg_id": "2015-7ec8cd76-8ed7-4360-ac32-2e881273a7c2",
      "topic": "io.pagure.dev.pagure.project.forked",
      "msg": {
        "project": {
          "description": "",
          "parent": {
            "description": "",
            "parent": None,
            "project_docs": True,
            "issue_tracker": True,
            "user": {
              "fullname": "ralph",
              "emails": [
                "ralph@fedoraproject.org"
              ],
              "name": "ralph"
            },
            "date_created": "1426595173",
            "id": 5,
            "name": "fedmsg"
          },
          "project_docs": True,
          "issue_tracker": True,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          },
          "date_created": "1427453169",
          "id": 8,
          "name": "fedmsg"
        },
        "agent": "pingou"
      }
    }


class TestNewPullRequestComment(Base):
    """ These messages are published when a someone commented on a
    pull-request of a project on `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.pull-request.comment.added"
    expected_subti = 'pingou commented on the pull-request#6 of '\
        'project "test"'
    expected_link = "https://pagure.io/test/pull-request/6"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/test', 'pull-request/6'])
    msg = {
      "i": 2,
      "timestamp": 1427457362,
      "msg_id": "2015-cbf24329-b51c-4160-983c-ffa45ef63863",
      "topic": "io.pagure.dev.pagure.pull-request.comment.added",
      "msg": {
        "pullrequest": {
          "status": True,
          "branch_from": "master",
          "uid": "0a7d6b626b934511b6355dd48926916a",
          "title": "test request",
          "commit_start": "788efeaaf86bde8618f594a8181abb402e1dd904",
          "project": {
            "description": "test project",
            "parent": None,
            "project_docs": True,
            "issue_tracker": True,
            "user": {
              "fullname": "Pierre-YvesChibon",
              "emails": [
                "pingou@fedoraproject.org"
              ],
              "name": "pingou"
            },
            "date_created": "1426500194",
            "id": 1,
            "name": "test"
          },
          "commit_stop": "5ca3e1c7ccff3327ebeb2f07eaa9bf3820d3f5c8",
          "repo_from": {
            "description": "test project",
            "parent": {
              "description": "test project",
              "parent": None,
              "project_docs": True,
              "issue_tracker": True,
              "user": {
                "fullname": "Pierre-YvesChibon",
                "emails": [
                  "pingou@fedoraproject.org"
                ],
                "name": "pingou"
              },
              "date_created": "1426500194",
              "id": 1,
              "name": "test"
            },
            "project_docs": True,
            "issue_tracker": True,
            "user": {
              "fullname": "Pierre-YvesChibon",
              "emails": [
                "pingou@fedoraproject.org"
              ],
              "name": "pingou"
            },
            "date_created": "1426843440",
            "id": 6,
            "name": "test"
          },
          "comments": [
            {
              "comment": "This is looking good!",
              "parent": None,
              "filename": None,
              "user": {
                "fullname": "Pierre-YvesChibon",
                "emails": [
                  "pingou@fedoraproject.org"
                ],
                "name": "pingou"
              },
              "commit": None,
              "date_created": "1427453701",
              "line": None,
              "id": 16
            }
          ],
          "branch": "master",
          "date_created": "1426843718",
          "id": 6,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          }
        },
        "agent": "pingou"
      }
    }


class TestNewPullRequestclosed(Base):
    """ These messages are published when a someone closed a pull-request
    of a project on `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.pull-request.closed"
    expected_subti = 'pingou closed (without merging) the pull-request#6 '\
        'of project "test"'
    expected_link = "https://pagure.io/test/pull-request/6"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/test', 'pull-request/6'])
    msg = {
      "i": 2,
      "timestamp": 1427458544,
      "msg_id": "2015-c9636fda-3a4c-452b-85ee-870e29f63a03",
      "topic": "io.pagure.dev.pagure.pull-request.closed",
      "msg": {
        "pullrequest": {
          "status": False,
          "branch_from": "master",
          "uid": "0a7d6b626b934511b6355dd48926916a",
          "title": "test request",
          "commit_start": "788efeaaf86bde8618f594a8181abb402e1dd904",
          "project": {
            "description": "test project",
            "parent": None,
            "project_docs": True,
            "issue_tracker": True,
            "user": {
              "fullname": "Pierre-YvesChibon",
              "emails": [
                "pingou@fedoraproject.org"
              ],
              "name": "pingou"
            },
            "date_created": "1426500194",
            "id": 1,
            "name": "test"
          },
          "commit_stop": "5ca3e1c7ccff3327ebeb2f07eaa9bf3820d3f5c8",
          "repo_from": {
            "description": "test project",
            "parent": {
              "description": "test project",
              "parent": None,
              "project_docs": True,
              "issue_tracker": True,
              "user": {
                "fullname": "Pierre-YvesChibon",
                "emails": [
                  "pingou@fedoraproject.org"
                ],
                "name": "pingou"
              },
              "date_created": "1426500194",
              "id": 1,
              "name": "test"
            },
            "project_docs": True,
            "issue_tracker": True,
            "user": {
              "fullname": "Pierre-YvesChibon",
              "emails": [
                "pingou@fedoraproject.org"
              ],
              "name": "pingou"
            },
            "date_created": "1426843440",
            "id": 6,
            "name": "test"
          },
          "comments": [
            {
              "comment": "Sorry but this won't do",
              "parent": None,
              "filename": None,
              "user": {
                "fullname": "Pierre-YvesChibon",
                "emails": [
                  "pingou@fedoraproject.org"
                ],
                "name": "pingou"
              },
              "commit": None,
              "date_created": "1427453701",
              "line": None,
              "id": 16
            },
          ],
          "branch": "master",
          "date_created": "1426843718",
          "id": 6,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          }
        },
        "agent": "pingou",
        "merged": False
      }
    }


class TestNewPullRequestMerged(Base):
    """ These messages are published when a someone merged a pull-request
    of a project on `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.pull-request.closed"
    expected_subti = 'pingou merged the pull-request#7 of project "test"'
    expected_link = "https://pagure.io/test/pull-request/7"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/test', 'pull-request/7'])
    msg = {
      "i": 3,
      "timestamp": 1427458778,
      "msg_id": "2015-22ec6669-91fe-4c32-b324-db80fba696dd",
      "topic": "io.pagure.dev.pagure.pull-request.closed",
      "msg": {
        "pullrequest": {
          "status": False,
          "branch_from": "master",
          "uid": "d4182a2ac2d541d884742d3037c26e56",
          "title": "test request",
          "commit_start": "788efeaaf86bde8618f594a8181abb402e1dd904",
          "project": {
            "description": "test project",
            "parent": None,
            "project_docs": True,
            "issue_tracker": True,
            "user": {
              "fullname": "Pierre-YvesChibon",
              "emails": [
                "pingou@fedoraproject.org"
              ],
              "name": "pingou"
            },
            "date_created": "1426500194",
            "id": 1,
            "name": "test"
          },
          "commit_stop": "5ca3e1c7ccff3327ebeb2f07eaa9bf3820d3f5c8",
          "repo_from": {
            "description": "test project",
            "parent": {
              "description": "test project",
              "parent": None,
              "project_docs": True,
              "issue_tracker": True,
              "user": {
                "fullname": "Pierre-YvesChibon",
                "emails": [
                  "pingou@fedoraproject.org"
                ],
                "name": "pingou"
              },
              "date_created": "1426500194",
              "id": 1,
              "name": "test"
            },
            "project_docs": True,
            "issue_tracker": True,
            "user": {
              "fullname": "Pierre-YvesChibon",
              "emails": [
                "pingou@fedoraproject.org"
              ],
              "name": "pingou"
            },
            "date_created": "1426843440",
            "id": 6,
            "name": "test"
          },
          "comments": [
            {
              "comment": "awesome!",
              "parent": None,
              "filename": "test",
              "user": {
                "fullname": "Pierre-YvesChibon",
                "emails": [
                  "pingou@fedoraproject.org"
                ],
                "name": "pingou"
              },
              "commit": "fa72f315373ec5f98f2b08c8ffae3645c97aaad2",
              "date_created": "1426843778",
              "line": 5,
              "id": 1
            }
          ],
          "branch": "master",
          "date_created": "1426843732",
          "id": 7,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          }
        },
        "agent": "pingou",
        "merged": True
      }
    }


class TestNewPullRequestNew(Base):
    """ These messages are published when a someone opens a new pull-request
    on a project on `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.pull-request.new"
    expected_subti = 'pingou opened the pull-request#21: "Improve loading '\
        'speed" for the project "test"'
    expected_link = "https://pagure.io/test/pull-request/21"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/test', 'pull-request/21'])
    msg = {
      "i": 4,
      "timestamp": 1427459070,
      "msg_id": "2015-1f03dc6a-3a0b-4b09-a06d-e4ca7d374729",
      "topic": "io.pagure.dev.pagure.pull-request.new",
      "msg": {
        "pullrequest": {
          "status": True,
          "branch_from": "test",
          "uid": "2bf721f0fbd34977aab78b5e1959e504",
          "title": "Improve loading speed",
          "commit_start": None,
          "project": {
            "description": "test project",
            "parent": None,
            "project_docs": True,
            "issue_tracker": True,
            "user": {
              "fullname": "Pierre-YvesChibon",
              "emails": [
                "pingou@fedoraproject.org"
              ],
              "name": "pingou"
            },
            "date_created": "1426500194",
            "id": 1,
            "name": "test"
          },
          "commit_stop": None,
          "repo_from": {
            "description": "test project",
            "parent": {
              "description": "test project",
              "parent": None,
              "project_docs": True,
              "issue_tracker": True,
              "user": {
                "fullname": "Pierre-YvesChibon",
                "emails": [
                  "pingou@fedoraproject.org"
                ],
                "name": "pingou"
              },
              "date_created": "1426500194",
              "id": 1,
              "name": "test"
            },
            "project_docs": True,
            "issue_tracker": True,
            "user": {
              "fullname": "Pierre-YvesChibon",
              "emails": [
                "pingou@fedoraproject.org"
              ],
              "name": "pingou"
            },
            "date_created": "1426843440",
            "id": 6,
            "name": "test"
          },
          "comments": [],
          "branch": "master",
          "date_created": "1427455470",
          "id": 21,
          "user": {
            "fullname": "Pierre-YvesChibon",
            "emails": [
              "pingou@fedoraproject.org"
            ],
            "name": "pingou"
          }
        },
        "agent": "pingou"
      }
    }


class TestPullRequestFlagAdded(Base):
    """ These messages are published when a someone flags a pull-request
    on a project on `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.pull-request.flag.added"
    expected_subti = 'Jenkins flagged test #1 with "Tests failed"'
    expected_link = "https://pagure.io/test/pull-request/1"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/test', 'pull-request/21'])
    msg = {
          "username": "pingou",
          "i": 3,
          "timestamp": 1433167960,
          "msg_id": "2015-e7094e2a-1259-49da-91f5-635e81011ffa",
          "topic": "io.pagure.dev.pagure.pull-request.flag.added",
          "msg": {
            "flag": {
              "comment": "Tests failed",
              "username": "Jenkins",
              "uid": "jenkins_build_pagure_100+seed",
              "url": "http://jenkins.cloud.fedoraproject.org/",
              "percent": "0",
              "pull_request_uid": "cb0cc178203046fe86f675779b31b913",
              "user": {
                "fullname": "PY C",
                "default_email": "bar@pingou.com",
                "emails": [
                  "bar@pingou.com",
                  "foo@pingou.com"
                ],
                "name": "pingou"
              },
              "date_created": "1433160759"
            },
            "pullrequest": {
              "status": true,
              "branch_from": "master",
              "uid": "cb0cc178203046fe86f675779b31b913",
              "title": "test pull-request",
              "commit_start": null,
              "project": {
                "description": "test project #1",
                "parent": null,
                "settings": {
                  "Minimum_score_to_merge_pull-request": -1,
                  "Web-hooks": null,
                  "project_documentation": true,
                  "pull_requests": true,
                  "Only_assignee_can_merge_pull-request": false,
                  "issue_tracker": true
                },
                "user": {
                  "fullname": "PY C",
                  "default_email": "bar@pingou.com",
                  "emails": [
                    "bar@pingou.com",
                    "foo@pingou.com"
                  ],
                  "name": "pingou"
                },
                "date_created": "1433160759",
                "id": 1,
                "name": "test"
              },
              "commit_stop": null,
              "repo_from": {
                "description": "test project #1",
                "parent": null,
                "settings": {
                  "Minimum_score_to_merge_pull-request": -1,
                  "Web-hooks": null,
                  "project_documentation": true,
                  "pull_requests": true,
                  "Only_assignee_can_merge_pull-request": false,
                  "issue_tracker": true
                },
                "user": {
                  "fullname": "PY C",
                  "default_email": "bar@pingou.com",
                  "emails": [
                    "bar@pingou.com",
                    "foo@pingou.com"
                  ],
                  "name": "pingou"
                },
                "date_created": "1433160759",
                "id": 1,
                "name": "test"
              },
              "assignee": null,
              "comments": [],
              "branch": "master",
              "date_created": "1433160759",
              "id": 1,
              "user": {
                "fullname": "PY C",
                "default_email": "bar@pingou.com",
                "emails": [
                  "bar@pingou.com",
                  "foo@pingou.com"
                ],
                "name": "pingou"
              }
            },
            "agent": "pingou"
          }
        }


class TestPullRequestFlagUpdated(Base):
    """ These messages are published when a someone updates a flag on a
    pull-request on a project on `pagure <https://pagure.io>`_.
    """
    expected_title = "pagure.pull-request.flag.updated"
    expected_subti = 'Jenkins updated the flag of test #1 with '\
        '"Tests passed"'
    expected_link = "https://pagure.io/test/pull-request/1"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c" + \
        "?s=64&d=retro"
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['project/test', 'pull-request/21'])
    msg = {
          "username": "pingou",
          "i": 4,
          "timestamp": 1433167960,
          "msg_id": "2015-e7094e2a-1259-49da-91f5-635e81011ffa",
          "topic": "io.pagure.dev.pagure.pull-request.flag.added",
          "msg": {
            "flag": {
              "comment": "Tests passed",
              "username": "Jenkins",
              "uid": "jenkins_build_pagure_101+seed",
              "url": "http://jenkins.cloud.fedoraproject.org/",
              "percent": "100",
              "pull_request_uid": "cb0cc178203046fe86f675779b31b913",
              "user": {
                "fullname": "PY C",
                "default_email": "bar@pingou.com",
                "emails": [
                  "bar@pingou.com",
                  "foo@pingou.com"
                ],
                "name": "pingou"
              },
              "date_created": "1433160759"
            },
            "pullrequest": {
              "status": true,
              "branch_from": "master",
              "uid": "cb0cc178203046fe86f675779b31b913",
              "title": "test pull-request",
              "commit_start": null,
              "project": {
                "description": "test project #1",
                "parent": null,
                "settings": {
                  "Minimum_score_to_merge_pull-request": -1,
                  "Web-hooks": null,
                  "project_documentation": true,
                  "pull_requests": true,
                  "Only_assignee_can_merge_pull-request": false,
                  "issue_tracker": true
                },
                "user": {
                  "fullname": "PY C",
                  "default_email": "bar@pingou.com",
                  "emails": [
                    "bar@pingou.com",
                    "foo@pingou.com"
                  ],
                  "name": "pingou"
                },
                "date_created": "1433160759",
                "id": 1,
                "name": "test"
              },
              "commit_stop": null,
              "repo_from": {
                "description": "test project #1",
                "parent": null,
                "settings": {
                  "Minimum_score_to_merge_pull-request": -1,
                  "Web-hooks": null,
                  "project_documentation": true,
                  "pull_requests": true,
                  "Only_assignee_can_merge_pull-request": false,
                  "issue_tracker": true
                },
                "user": {
                  "fullname": "PY C",
                  "default_email": "bar@pingou.com",
                  "emails": [
                    "bar@pingou.com",
                    "foo@pingou.com"
                  ],
                  "name": "pingou"
                },
                "date_created": "1433160759",
                "id": 1,
                "name": "test"
              },
              "assignee": null,
              "comments": [],
              "branch": "master",
              "date_created": "1433160759",
              "id": 1,
              "user": {
                "fullname": "PY C",
                "default_email": "bar@pingou.com",
                "emails": [
                  "bar@pingou.com",
                  "foo@pingou.com"
                ],
                "name": "pingou"
              }
            },
            "agent": "pingou"
          }
        }


add_doc(locals())

if __name__ == '__main__':
    unittest.main()



import fedmsg.tests.test_meta
import arrow

class TestPkgdbConglomerateCommentSubject(
        fedmsg.tests.test_meta.ConglomerateBase):
    originals = [{
        "source_name": "datanommer",
        "i": 25,
        "timestamp": 1416428310.0,
        "msg_id": "2014-9e46f5ce-4881-4497-aec4-89cf83332b2d",
        "topic": "org.fedoraproject.prod.pkgdb.acl.update",
        "source_version": "0.6.4",
        "msg": {
            "status": "Approved",
            "username": "mcepl",
            "package_listing": {
                "status": "Approved",
                "point_of_contact": "mcepl",
                "package": {
                    "status": "Approved",
                    "upstream_url": "https://cryptography.io/",
                    "description": "",
                    "creation_date": 1416428295.0,
                    "acls": [],
                    "summary": "PyCA's cryptography library",
                    "review_url": "https://bugzilla.redhat.com/1114267",
                    "name": "python-cryptography"
                },
                "collection": {
                    "status": "Under Development",
                    "dist_tag": ".fc22",
                    "koji_name": "rawhide",
                    "name": "Fedora",
                    "version": "devel",
                    "branchname": "master"
                },
                "critpath": False,
                "status_change": 1416428298.0
            },
            "package_name": "python-cryptography",
            "agent": "limb",
            "previous_status": "",
            "acl": "approveacls"
        }
    },
    {
        "source_name": "datanommer",
        "i": 20,
        "timestamp": 1416428307.0,
        "msg_id": "2014-06ef29dd-adb5-47d8-92aa-f1ead0c4d8f1",
        "topic": "org.fedoraproject.prod.pkgdb.acl.update",
        "source_version": "0.6.4",
        "msg": {
            "status": "Approved",
            "username": "mcepl",
            "package_listing": {
                "status": "Approved",
                "point_of_contact": "mcepl",
                "package": {
                    "status": "Approved",
                    "upstream_url": "https://cryptography.io/",
                    "description": "",
                    "creation_date": 1416428295.0,
                    "acls": [],
                    "summary": "PyCA's cryptography library",
                    "review_url": "https://bugzilla.redhat.com/1114267",
                    "name": "python-cryptography"
                },
                "collection": {
                    "status": "Under Development",
                    "dist_tag": ".el7",
                    "koji_name": "epel7",
                    "name": "Fedora EPEL",
                    "version": "7",
                    "branchname": "epel7"
                },
                "acls": [ {
                    "fas_name": "mcepl",
                    "status": "Approved",
                    "acl": "commit"
                }, {
                    "fas_name": "mcepl",
                    "status": "Approved",
                    "acl": "watchbugzilla"
                }, {
                    "fas_name": "mcepl",
                    "status": "Approved",
                    "acl": "watchcommits"
                } ],
                "critpath": False,
                "status_change": 1416428298.0
            },
            "package_name": "python-cryptography",
            "agent": "limb",
            "previous_status": "",
            "acl": "watchcommits"
        }
    },
    ]
    expected = [{
        'subtitle': 'limb changed mcepl\'s approveacls and watchcommits '
        'permissions on python-cryptography (epel7 and master) '
        'to Approved.',
        'link': 'https://admin.fedoraproject.org/pkgdb/packager/mcepl/',

        'icon': 'https://apps.fedoraproject.org/packages/images/'
        'icons/package_128x128.png',
        'secondary_icon': 'https://seccdn.libravatar.org/avatar/'
        'f0496e0b40a4e1e780cb09ee8a89870aa0f90643fa36b095a9057be4c61ec3b6'
        '?s=64&d=retro',

        'start_time': 1416428307.0,
        'end_time': 1416428310.0,
        'timestamp': 1416428308.5,

        'human_time': arrow.get(1416428308.5).humanize(),

        'usernames': set(['mcepl', 'limb']),
        'packages': set(['python-cryptography']),
        'topics': set(['org.fedoraproject.prod.pkgdb.acl.update']),
        'categories': set(['pkgdb']),
        'msg_ids': [
            '2014-9e46f5ce-4881-4497-aec4-89cf83332b2d',
            '2014-06ef29dd-adb5-47d8-92aa-f1ead0c4d8f1',
        ],
    }]



# This file is part of fedmsg.
# Copyright (C) 2012-2015 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Ralph Bean <rbean@redhat.com>
#
""" Tests for fedmsg.meta """

import unittest

from fedmsg_meta_fedora_infrastructure.tests.base import Base

from fedmsg_meta_fedora_infrastructure.tests.common import add_doc


class TestZanataMilestone(Base):
    """ Fedora uses `zanata <https://fedora.zanata.org>`_ for translations and
    they can ping us back when documents reach various milestones.  Here's
    an example of a document reaching 100% status:
    """
    expected_title = "zanata.document.milestone.event"
    expected_subti = "foo.txt from the webhooks-dummy project is now " + \
        "100% translated in the 'af' locale"
    expected_icon = 'https://pbs.twimg.com/profile_images/' + \
        '378800000417679469/47eb45c6205aa9f2cdb8705e6d46745c_normal.png'
    expected_secondary_icon = expected_icon
    expected_link = 'https://fedora.zanata.org/' + \
        'iteration/view/webhooks-dummy/0.1/languages/af'
    expected_usernames = set([])
    expected_packages = set([])
    expected_objects = set([
        'webhooks-dummy/0.1/languages/af',
    ])

    msg = {
        "i": 16,
        "msg": {
            "project": "webhooks-dummy",
            "version": "0.1",
            "docId": "foo.txt",
            "locale": "af",
            "milestone": "100% Translated",
            "eventType": "org.zanata.event.DocumentMilestoneEvent",
        },
        "topic": "org.fedoraproject.dev.zanata.document.milestone.event",
        "timestamp": 1345572862.556145
    }


add_doc(locals())

if __name__ == '__main__':
    unittest.main()



import fedmsg.meta.base
from fedmsg_meta_fedora_infrastructure.fasshim import avatar_url


class AbstractPkgdbACLsConglomerator(fedmsg.meta.base.BaseConglomerator):
    def can_handle(self, msg, **config):
        return 'pkgdb.acl.update' in msg['topic']

    def possessive(self, name):
        """ Given a name, return the possessive form. """
        return self._("{name}'s").format(name=name)

    def merge(self, constituents, **config):
        ms = constituents  # shorthand
        agents = self.list_to_series([m['msg']['agent'] for m in ms])
        usernames = self.list_to_series([
            self.possessive(m['msg']['username']) for m in ms
        ])
        acls = self.list_to_series([m['msg']['acl'] for m in ms])
        packages = self.list_to_series([m['msg']['package_name'] for m in ms])
        statuses = self.list_to_series([m['msg']['status'] for m in ms])
        branches = self.list_to_series([
            m['msg']['package_listing']['collection']['branchname']
            for m in ms])

        subtitle = '{agents} changed {usernames} {acls} permissions on ' + \
            '{packages} ({branches}) to {statuses}.'

        tmpl = self.produce_template(constituents, **config)
        tmpl['subtitle'] = subtitle.format(
            agents=agents,
            usernames=usernames,
            acls=acls,
            packages=packages,
            branches=branches,
            statuses=statuses,
        )

        default = tmpl['icon']

        # These are the only two keys that vary amongst our concrete children.
        tmpl['secondary_icon'] = self.get_secondary_icon(constituents, default)
        tmpl['link'] = self.get_link(constituents)

        return tmpl


class BySubject(AbstractPkgdbACLsConglomerator):
    def matches(self, a, b, **config):
        """ The changes must all be **to** the same pkgdb user """
        a, b = a['msg'], b['msg']
        if a['username'] != b['username']:
            return False
        return True

    def get_secondary_icon(self, constituents, default):
        username = constituents[0]['msg']['username']
        return avatar_url(username)

    def get_link(self, constituents):
        username = constituents[0]['msg']['username']
        base = 'https://admin.fedoraproject.org/pkgdb/packager/%s/'
        return base % username


class ByAgent(AbstractPkgdbACLsConglomerator):
    def matches(self, a, b, **config):
        """ The changes must all be **by** the same pkgdb user """
        a, b = a['msg'], b['msg']
        if a['agent'] != b['agent']:
            return False
        return True

    def get_secondary_icon(self, constituents, default):
        username = constituents[0]['msg']['agent']
        return avatar_url(username)

    def get_link(self, constituents):
        username = constituents[0]['msg']['agent']
        base = 'https://admin.fedoraproject.org/pkgdb/packager/%s/'
        return base % username


class ByPackage(AbstractPkgdbACLsConglomerator):
    def matches(self, a, b, **config):
        """ The changes must all be **on** the same package """
        a, b = a['msg'], b['msg']
        if a['package_name'] != b['package_name']:
            return False
        return True

    def get_secondary_icon(self, constituents, default):
        return default

    def get_link(self, constituents):
        package = constituents[0]['msg']['package_name']
        base = 'https://admin.fedoraproject.org/pkgdb/package/%s/'
        return base % package



# This file is part of fedmsg.
# Copyright (C) 2014 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  David Gay <oddshocks@riseup.net>
#
""" Tests for Fedimg messages """

import unittest

from fedmsg.tests.test_meta import Base

from .common import add_doc


class TestImageUploadStart(Base):
    """ These messages are published when an image upload has started. 
        At this point, Fedimg has picked up a completed Koji
        createImage task and will begin the process of registering
        the .raw.xz file as as an image with a cloud provider. """

    expected_title = "fedimg.image.upload"
    image_name = "fedora-cloud-base-rawhide-20140604.x86_64"
    dest = "EC2-eu-west-1"
    expected_subti = "{0} started uploading to {1}".format(image_name,
                                                                 dest)
    expected_link = None
    expected_icon = 'https://apps.fedoraproject.org/img/icons/fedimg.png'
    expected_secondary_icon = None
    expected_packages = set([])
    expected_usernames = set([])
    expected_objects = set(['image/upload/started'])
    msg = {
        u'i': 1,
        u'msg': {
            u'image_url': 'https://kojipkgs.fedoraproject.org//work/'
                          'tasks/5144/6925144/fedora-cloud-base-'
                          'rawhide-20140604.x86_64.raw.xz',
            u'image_name': 'fedora-cloud-base-rawhide-20140604.x86_64',
            u'destination': 'EC2-eu-west-1',
            u'status': 'started',
        },
        u'topic': u'org.fedoraproject.stg.fedimg.image.upload',
        u'username': u'fedimg',
        u'timestamp': 1371498303.125771,
    }


class TestImageUploadComplete(Base):
    """ These messages are published when an image upload finishes.
        At this point, Fedimg has completed registering a .raw.xz
        image with a cloud provider. """

    expected_title = "fedimg.image.upload"
    image_name = "fedora-cloud-base-rawhide-20140604.x86_64"
    dest = "EC2-eu-west-1"
    ami_id = 'ami-1234fda'
    virt_type = 'HVM'
    vol_type = 'gp2'
    expected_subti = "{0} finished uploading to {1} ({2}, {3}, {4})".format(
            image_name, dest, ami_id, virt_type, vol_type)
    expected_link = None
    expected_icon = 'https://apps.fedoraproject.org/img/icons/fedimg.png'
    expected_secondary_icon = None
    expected_packages = set([])
    expected_usernames = set([])
    expected_objects = set(['image/upload/completed'])
    msg = {
        u'i': 1,
        u'msg': {
            u'image_url': 'https://kojipkgs.fedoraproject.org//work/'
                          'tasks/5144/6925144/fedora-cloud-base-'
                          'rawhide-20140604.x86_64.raw.xz',
            u'image_name': 'fedora-cloud-base-rawhide-20140604.x86_64',
            u'destination': 'EC2-eu-west-1',
            u'status': 'completed',
            u'extra': {
                u'id': 'ami-1234fda',
                u'virt_type': 'HVM',
                u'vol_type': 'gp2',
            },
        },
        u'topic': u'org.fedoraproject.stg.fedimg.image.upload',
        u'username': u'fedimg',
        u'timestamp': 1371498303.125771,
    }


class TestImageTestStart(Base):
    """ These messages are published when an image test has started.
        At this point, Fedimg tries to start an instance of a
        image that it registered in the previous step, and check
        to see that it's running properly. """

    expected_title = "fedimg.image.test"
    image_name = "fedora-cloud-base-rawhide-20140604.x86_64"
    dest = "EC2-eu-west-1"
    ami_id = 'ami-1234fda'
    virt_type = 'HVM'
    vol_type = 'gp2'
    expected_subti = "{0} started testing on {1} ({2}, {3}, {4})".format(
            image_name, dest, ami_id, virt_type, vol_type)
    expected_link = None
    expected_icon = 'https://apps.fedoraproject.org/img/icons/fedimg.png'
    expected_secondary_icon = None
    expected_packages = set([])
    expected_usernames = set([])
    expected_objects = set(['image/test/started'])
    msg = {
        u'i': 1,
        u'msg': {
            u'image_url': 'https://kojipkgs.fedoraproject.org//work/'
                          'tasks/5144/6925144/fedora-cloud-base-'
                          'rawhide-20140604.x86_64.raw.xz',
            u'image_name': 'fedora-cloud-base-rawhide-20140604.x86_64',
            u'destination': 'EC2-eu-west-1',
            u'status': 'started',
            u'extra': {
                u'id': 'ami-1234fda',
                u'virt_type': 'HVM',
                u'vol_type': 'gp2',
            },
        },
        u'topic': u'org.fedoraproject.stg.fedimg.image.test',
        u'username': u'fedimg',
        u'timestamp': 1371498303.125771,
    }

add_doc(locals())

if __name__ == '__main__':
    unittest.main()



# This file is part of fedmsg.
# Copyright (C) 2014 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Ralph Bean <rbean@redhat.com>
#
""" Tests for the-new-hotness messages """

import unittest

from fedmsg_meta_fedora_infrastructure.tests.base import Base

from .common import add_doc


class TestHotnessBugFollowupScratchBuild(Base):
    """ These messages are published by a backend service called
    `the-new-hotness <https://github.com/fedora-infra/the-new-hotness>`_.
    It watches for new upstream release notifications from
    `release-monitoring.org <https://release-monitoring.org>`_ and in response
    it files bugs in `bugzilla <https://bugzilla.redhat.com>`_ and kicks off
    scratch builds in `koji <https://koji.fedoraproject.org/koji>`_.

    These kinds of messages get published in a couple different scenarios:

    - After having filed a bug and kicked off a scratch build, the-new-hotness
      **notices that one of its scratch builds completes** and follows up on a
      ticket.
    - After having filed a bug, the-new-hotness **notices that the package
      owner has completed a real build of the package** and follows up on a
      ticket.

    The message here is an example of the **first case** where the daemon
    notices **one of its own scratch builds**:
    """

    expected_title = "hotness.update.bug.followup"
    expected_subti = "scratch build of " + \
        "perl-Makefile-DOM-0.007-1.el7.src.rpm " + \
        "for RHBZ#1143475 completed"
    expected_link = "https://partner-bugzilla.redhat.com/show_bug.cgi?id=1143475"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = expected_icon
    expected_packages = set([])
    expected_usernames = set([])
    expected_objects = set([
        'bugs/1143475',
    ])
    msg = {
        "username": "fedmsg",
        "i": 5,
        "timestamp": 1416513240,
        "msg_id": "2014-c1fc1501-a043-4e5a-9a50-3076bb6d5089",
        "crypto": "x509",
        "topic": "org.fedoraproject.stg.hotness.update.bug.followup",
        "msg": {
            "trigger": {
                "username": "apache",
                "i": 1,
                "timestamp": 1416513251,
                "msg_id": "2014-786f6cfc-c76f-4cef-a791-6a6166861ab1",
                "crypto": "x509",
                "topic": "org.fedoraproject.stg.buildsys.task.state.change",
                "msg": {
                    "info": {
                        "parent": None,
                        "completion_time": None,
                        "start_time": "2014-11-20 19:54:11.737219",
                        "request": [
                            "cli-build/1416513248.864099.haYhDKay/"
                            "perl-Makefile-DOM-0.007-1.el7.src.rpm",
                            "rawhide",
                            { "scratch": True }
                        ],
                        "waiting": None,
                        "awaited": None,
                        "method": "build",
                        "priority": 50,
                        "channel_id": 1,
                        "state": 1,
                        "create_time": "2014-11-20 19:54:09.028052",
                        "id": 174,
                        "owner": 1127,
                        "host_id": 3,
                        "label": None,
                        "arch": "noarch",
                        "children": []
                    },
                    "old": "OPEN",
                    "attribute": "state",
                    "id": 174,
                    "instance": "primary",
                    "owner": "hotness",
                    "new": "CLOSED",
                    "srpm": "perl-Makefile-DOM-0.007-1.el7.src.rpm",
                    "method": "build"
                }
            },
            "bug": { "bug_id": 1143475 },
        }
    }


class TestHotnessBugFollowupRealBuild(Base):
    """ These messages are published by a backend service called
    `the-new-hotness <https://github.com/fedora-infra/the-new-hotness>`_.
    It watches for new upstream release notifications from
    `release-monitoring.org <https://release-monitoring.org>`_ and in response
    it files bugs in `bugzilla <https://bugzilla.redhat.com>`_ and kicks off
    scratch builds in `koji <https://koji.fedoraproject.org/koji>`_.

    These kinds of messages get published in a couple different scenarios:

    - After having filed a bug and kicked off a scratch build, the-new-hotness
      **notices that one of its scratch builds completes** and follows up on a
      ticket.
    - After having filed a bug, the-new-hotness **notices that the package
      owner has completed a real build of the package** and follows up on a
      ticket.

    The message here is an example of the **second case**, where the daemon
    notices a **real build**:
    """

    expected_title = "hotness.update.bug.followup"
    expected_subti = "jmlich's real build of " + \
        "gd-2.1.1-1.fc22 for RHBZ#1144231 completed"
    expected_link = "https://partner-bugzilla.redhat.com/show_bug.cgi?id=1144231"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://apps.fedoraproject.org/packages" + \
        "/images/icons/gd.png"
    expected_packages = set(['gd'])
    expected_usernames = set(['jmlich'])
    expected_objects = set(['bugs/1144231'])
    msg = {
        u'username': u'fedmsg',
        u'msg_id': u'2015-f6b6e30c-bdf7-4200-8d53-7d9c54ce1749',
        u'topic': u'org.fedoraproject.stg.hotness.update.bug.followup',
        u'msg': {
            u'trigger': {
                u'username ': u'apache',
                u'msg_id': u'2015-a4653ee6-2ec7-42af-91a9-57c54ef9448c',
                u'topic': u'org.fedoraproject.prod.buildsys.build.state.change',
                u'msg': {
                    u'build_id': 603868,
                    u'old': 0,
                    u'name': u'gd',
                    u'task_id': 8615864,
                    u'attribute': u'state',
                    u'instance': u'primary',
                    u'version': u'2.1.1',
                    u'owner': u'jmlich',
                    u'new': 1,
                    u'release': u'1.fc22',
                },
            },
            u'bug': {u'bug_id': 1144231},
        },
    }


class TestHotnessBugFile(Base):
    """ These messages are published by a backend service called
    `the-new-hotness <https://github.com/fedora-infra/the-new-hotness>`_.
    It watches for new upstream release notifications from
    `release-monitoring.org <https://release-monitoring.org>`_ and in response
    it files bugs in `bugzilla <https://bugzilla.redhat.com>`_ and kicks off
    scratch builds in `koji <https://koji.fedoraproject.org/koji>`_.

    These kinds of messages get published when a **bug gets filed** notifying
    packager owners that they should update their packages in rawhide.
    """

    expected_title = "hotness.update.bug.file"
    expected_subti = "the-new-hotness filed a bug on perl-Makefile-DOM"
    expected_link = "https://bugzilla.redhat.com/show_bug.cgi?id=1143475"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://apps.fedoraproject.org/packages" + \
        "/images/icons/perl-Makefile-DOM.png"
    expected_packages = set(['perl-Makefile-DOM'])
    expected_usernames = set([])
    expected_objects = set([
        'bugs/1143475',
        'projects/Makefile-DOM',
        'packages/perl-Makefile-DOM',
    ])
    msg = {
        "username": "fedmsg",
        "i": 5,
        "timestamp": 1416513240,
        "msg_id": "2014-c1fc1501-a043-4e5a-9a50-3076bb6d5089",
        "crypto": "x509",
        "topic": "org.fedoraproject.prod.hotness.update.bug.file",
        "msg": {
            "trigger": {
                "username": "ralph",
                "i": 1,
                "timestamp": 1416513232,
                "msg_id": "2014-7c19ff86-e6ef-4ccb-91b7-e836f33c7350",
                "crypto": "x509",
                "topic": "org.fedoraproject.stg.anitya.project.version.update",
                "msg": {
                    "project": {
                        "regex": None,
                        "name": "Makefile-DOM",
                        "created_on": 1412175050.0,
                        "version": "0.007",
                        "version_url": None,
                        "updated_on": 1416358331.0,
                        "homepage": "http://search.cpan.org/dist/"
                        "Makefile-DOM/",
                        "id": 3052,
                        "backend": "CPAN (perl)"
                    },
                    "message": {
                        "versions": [
                            "0.006",
                            "0.007"
                        ],
                        "old_version": "0.006",
                        "agent": "anitya",
                        "project": {
                            "regex": None,
                            "name": "Makefile-DOM",
                            "created_on": 1412175050.0,
                            "version": "0.007",
                            "version_url": None,
                            "updated_on": 1414068821.0,
                            "homepage": "http://search.cpan.org/dist/"
                            "Makefile-DOM/",
                            "id": 3052,
                            "backend": "CPAN (perl)"
                        },
                        "upstream_version": "0.007",
                        "packages": [
                            {
                                "package_name": "perl-Makefile-DOM",
                                "distro": "Fedora"
                            }
                        ]
                    },
                    "distro": None
                }
            },
            "bug": { "bug_id": 1143475 }
        }
    }


class TestHotnessDropAnitya(Base):
    """ These messages are published by a backend service called
    `the-new-hotness <https://github.com/fedora-infra/the-new-hotness>`_.
    It watches for new upstream release notifications from
    `release-monitoring.org <https://release-monitoring.org>`_ and in response
    it files bugs in `bugzilla <https://bugzilla.redhat.com>`_ and kicks off
    scratch builds in `koji <https://koji.fedoraproject.org/koji>`_.

    Sometimes, there is a new upstream release of something, but there is no
    explicit mapping in `release-monitoring.org
    <https://release-monitoring.org>`_ between that upstream project and a
    Fedora package.  In that event, no bugzilla bugs can be filed -- we don't
    know the **package name**.

    These kinds of messages get published when a new notification arrives, but
    **the upstream mapping for Fedora is absent** -- so the-new-hotness doesn't
    know what to do and just drops the event (but tells us about it via these
    messages).
    """

    expected_title = "hotness.update.drop"
    expected_subti = "the-new-hotness saw an update for apsw, but " + \
        "release-monitoring.org doesn't know what that project is called " + \
        "in Fedora land"
    expected_link = "https://release-monitoring.org/project/3772/"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = expected_icon
    expected_packages = set([])
    expected_usernames = set([])
    expected_objects = set(['projects/apsw'])
    msg = {
        "username": "fedmsg",
        "i": 2,
        "timestamp": 1416510033,
        "msg_id": "2014-187a78cc-83cf-476d-be91-2b8e6b0befbf",
        "crypto": "x509",
        "topic": "org.fedoraproject.stg.hotness.update.drop",
        "msg": {
            "reason": "anitya",
            "trigger": {
                "username": "anitya",
                "i": 1,
                "timestamp": 1416510031,
                "msg_id": "2014-86d41c9d-3ea0-4ee3-888b-ccf4e2544189",
                "crypto": "x509",
                "topic": "org.fedoraproject.stg.anitya.project.version.update",
                "msg": {
                    "project": {
                        "regex": None,
                        "name": "apsw",
                        "created_on": 1412175076.0,
                        "version": "3.8.7.1-r1",
                        "version_url": "rogerbinns/apsw",
                        "updated_on": 1416504528.0,
                        "homepage": "https://github.com/rogerbinns/apsw",
                        "id": 3772,
                        "backend": "Github"
                    },
                    "message": {
                        "versions": [
                            "3.8.7.1-r1"
                        ],
                        "old_version": "",
                        "agent": "anitya",
                        "project": {
                            "regex": None,
                            "name": "apsw",
                            "created_on": 1412175076.0,
                            "version": "3.8.7.1-r1",
                            "version_url": "rogerbinns/apsw",
                            "updated_on": 1416504528.0,
                            "homepage": "https://github.com/rogerbinns/apsw",
                            "id": 3772,
                            "backend": "Github"
                        },
                        "upstream_version": "3.8.7.1-r1",
                        "packages": []
                    },
                    "distro": None
                }
            }
        }
    }


class TestHotnessDropPkgdb(Base):
    """ These messages are published by a backend service called
    `the-new-hotness <https://github.com/fedora-infra/the-new-hotness>`_.
    It watches for new upstream release notifications from
    `release-monitoring.org <https://release-monitoring.org>`_ and in response
    it files bugs in `bugzilla <https://bugzilla.redhat.com>`_ and kicks off
    scratch builds in `koji <https://koji.fedoraproject.org/koji>`_.

    Before it tries to file a bugzilla ticket, it checks to see if the
    ``'monitor'`` setting is ``True`` for this package in the `Fedora PkgDB
    <https://admin.fedoraproject.org/pkgdb>`_.

    These kinds of messages get published when a new notification arrives, but
    **that monitor boolean was set to False for the given package** -- so
    the-new-hotness respects that and just drops the event (but tells us about
    it via these messages).
    """

    expected_title = "hotness.update.drop"
    expected_subti = "the-new-hotness saw an update for python-apsw, but " + \
        "pkgdb says the package owner is not interested in bugs being filed"
    expected_link = "https://release-monitoring.org/project/3772/"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://apps.fedoraproject.org/packages" + \
        "/images/icons/python-apsw.png"
    expected_packages = set(['python-apsw'])
    expected_usernames = set([])
    expected_objects = set(['projects/apsw', 'packages/python-apsw'])
    msg = {
        "username": "fedmsg",
        "i": 2,
        "timestamp": 1416510033,
        "msg_id": "2014-187a78cc-83cf-476d-be91-2b8e6b0befbf",
        "crypto": "x509",
        "topic": "org.fedoraproject.stg.hotness.update.drop",
        "msg": {
            "reason": "pkgdb",
            "trigger": {
                "username": "anitya",
                "i": 1,
                "timestamp": 1416510031,
                "msg_id": "2014-86d41c9d-3ea0-4ee3-888b-ccf4e2544189",
                "crypto": "x509",
                "topic": "org.fedoraproject.stg.anitya.project.version.update",
                "msg": {
                    "project": {
                        "regex": None,
                        "name": "apsw",
                        "created_on": 1412175076.0,
                        "version": "3.8.7.1-r1",
                        "version_url": "rogerbinns/apsw",
                        "updated_on": 1416504528.0,
                        "homepage": "https://github.com/rogerbinns/apsw",
                        "id": 3772,
                        "backend": "Github"
                    },
                    "message": {
                        "versions": [
                            "3.8.7.1-r1"
                        ],
                        "old_version": "",
                        "agent": "anitya",
                        "project": {
                            "regex": None,
                            "name": "apsw",
                            "created_on": 1412175076.0,
                            "version": "3.8.7.1-r1",
                            "version_url": "rogerbinns/apsw",
                            "updated_on": 1416504528.0,
                            "homepage": "https://github.com/rogerbinns/apsw",
                            "id": 3772,
                            "backend": "Github"
                        },
                        "upstream_version": "3.8.7.1-r1",
                        "packages": [
                            {
                                "package_name": "python-apsw",
                                "distro": "Fedora"
                            }
                        ]
                    },
                    "distro": None
                }
            }
        }
    }


class TestHotnessDropBugzilla(Base):
    """ These messages are published by a backend service called
    `the-new-hotness <https://github.com/fedora-infra/the-new-hotness>`_.
    It watches for new upstream release notifications from
    `release-monitoring.org <https://release-monitoring.org>`_ and in response
    it files bugs in `bugzilla <https://bugzilla.redhat.com>`_ and kicks off
    scratch builds in `koji <https://koji.fedoraproject.org/koji>`_.

    These kinds of messages get published when a new notification arrives, but
    **a bugzilla ticket has already been filed for that update** -- so
    the-new-hotness just drops the event (but tells us about it via these
    messages).
    """

    expected_title = "hotness.update.drop"
    expected_subti = "the-new-hotness saw an update for python-apsw, but " + \
        "a bugzilla ticket had already been filed"
    expected_link = "https://release-monitoring.org/project/3772/"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://apps.fedoraproject.org/packages" + \
        "/images/icons/python-apsw.png"
    expected_packages = set(['python-apsw'])
    expected_usernames = set([])
    expected_objects = set(['projects/apsw', 'packages/python-apsw'])
    msg = {
        "username": "fedmsg",
        "i": 2,
        "timestamp": 1416510033,
        "msg_id": "2014-187a78cc-83cf-476d-be91-2b8e6b0befbf",
        "crypto": "x509",
        "topic": "org.fedoraproject.stg.hotness.update.drop",
        "msg": {
            "reason": "bugzilla",
            "trigger": {
                "username": "anitya",
                "i": 1,
                "timestamp": 1416510031,
                "msg_id": "2014-86d41c9d-3ea0-4ee3-888b-ccf4e2544189",
                "crypto": "x509",
                "topic": "org.release-monitoring.prod.anitya.project.version.update",
                "msg": {
                    "project": {
                        "regex": None,
                        "name": "apsw",
                        "created_on": 1412175076.0,
                        "version": "3.8.7.1-r1",
                        "version_url": "rogerbinns/apsw",
                        "updated_on": 1416504528.0,
                        "homepage": "https://github.com/rogerbinns/apsw",
                        "id": 3772,
                        "backend": "Github"
                    },
                    "message": {
                        "versions": [
                            "3.8.7.1-r1"
                        ],
                        "old_version": "",
                        "agent": "anitya",
                        "project": {
                            "regex": None,
                            "name": "apsw",
                            "created_on": 1412175076.0,
                            "version": "3.8.7.1-r1",
                            "version_url": "rogerbinns/apsw",
                            "updated_on": 1416504528.0,
                            "homepage": "https://github.com/rogerbinns/apsw",
                            "id": 3772,
                            "backend": "Github"
                        },
                        "upstream_version": "3.8.7.1-r1",
                        "packages": [
                            {
                                "package_name": "python-apsw",
                                "distro": "Fedora"
                            }
                        ]
                    },
                    "distro": None
                }
            }
        }
    }


class TestHotnessMapFailAmbiguous(Base):
    """ These messages are published by a backend service called
    `the-new-hotness <https://github.com/fedora-infra/the-new-hotness>`_.
    It watches for new upstream release notifications from
    `release-monitoring.org <https://release-monitoring.org>`_ and in response
    it files bugs in `bugzilla <https://bugzilla.redhat.com>`_ and kicks off
    scratch builds in `koji <https://koji.fedoraproject.org/koji>`_.

    These kinds of messages get published when a new package gets added to
    Fedora and the-new-hotness **tries to add that package to
    release-monitoring.org**, but fails.
    """

    expected_title = "hotness.project.map"
    expected_subti = "hotness tried to map python-django-angular to an " + \
        "upstream project, but failed due to ambiguity.  3 other projects " + \
        "share the same homepage"
    expected_link = "https://bugzilla.redhat.com/1182533"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://apps.fedoraproject.org/packages" + \
        "/images/icons/python-django-angular.png"
    expected_packages = set(['python-django-angular'])
    expected_usernames = set([])
    expected_objects = set(['packages/python-django-angular'])
    msg = {
        'msg_id': '2015-30c4b30d-ca69-4c95-bad9-8e4c0b5d8fdb',
        'timestamp': 1421445401,
        'topic': u'org.fedoraproject.prod.hotness.project.map',
        'msg': {
            'success': False,
            'total': 3,
            'trigger': {
                u'msg_id': u'2015-b5cb92c6-9bdf-4807-ab29-2604ee93b407',
                u'timestamp': 1421445385,
                u'topic': u'org.fedoraproject.prod.pkgdb.package.new',
                u'msg': {
                    u'agent': u'limb',
                    u'package_listing': {
                        u'collection': {
                            u'branchname': u'master',
                            u'dist_tag': u'.fc22',
                            u'koji_name': u'rawhide',
                            u'name': u'Fedora',
                            u'status': u'Under Development',
                            u'version': u'devel'
                        },
                        u'critpath': False,
                        u'package': {
                            u'acls': [],
                            u'creation_date': 1421329015.0,
                            u'description': u'',
                            u'monitor': False,
                            u'name': u'python-django-angular',
                            u'review_url': u'https://bugzilla.redhat.com/'
                            '1182533',
                            u'status': u'Approved',
                            u'summary': u'Classes and utility functions to '
                            'integrate AngularJS with Django',
                            u'upstream_url': u'https://github.com/jrief/'
                            'django-angular',
                        },
                        u'point_of_contact': u'mrunge',
                        u'status': u'Approved',
                        u'status_change': 1421329016.0,
                    },
                    u'package_name': u'python-django-angular',
                },
            },
        },
    }


class TestHotnessMapMonitorToggle(Base):
    """ These messages are published by a backend service called
    `the-new-hotness <https://github.com/fedora-infra/the-new-hotness>`_.
    It watches for new upstream release notifications from
    `release-monitoring.org <https://release-monitoring.org>`_ and in response
    it files bugs in `bugzilla <https://bugzilla.redhat.com>`_ and kicks off
    scratch builds in `koji <https://koji.fedoraproject.org/koji>`_.

    These kinds of messages get published when a package has its monitoring
    flag toggled in pkgdb and the-new-hotness **tries to map that package in
    release-monitoring.org**, but fails.
    """

    expected_title = "hotness.project.map"
    expected_subti = "hotness tried to map perl-Digest-Perl-MD5 to an " + \
        "upstream project, but failed:  \"Could not determine backend for " + \
        "http://search.cpan.org/dist/Digest-Perl-MD5/\""
    expected_link = "http://search.cpan.org/dist/Digest-Perl-MD5/"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://apps.fedoraproject.org/packages" + \
        "/images/icons/perl-Digest-Perl-MD5.png"
    expected_packages = set(['perl-Digest-Perl-MD5'])
    expected_usernames = set([])
    expected_objects = set(['packages/perl-Digest-Perl-MD5'])
    msg = {
        "i": 20,
        "msg": {
        "reason": "Could not determine backend for "
        "http://search.cpan.org/dist/Digest-Perl-MD5/",
        "success": False,
        "trigger": {
            "crypto": "x509",
            "i": 1,
            "msg": {
                "agent": "fale",
                "package": {
                    "acls": [],
                    "creation_date": 1400070978.0,
                    "description": "A pure-perl implementation of Ron "
                    "Rivest's MD5 Algorithm.",
                    "monitor": True,
                    "name": "perl-Digest-Perl-MD5",
                    "review_url": "https://bugzilla.redhat.com/732484",
                    "status": "Approved",
                    "summary": "Perl implementation of Ron "
                    "Rivest's MD5 Algorithm",
                    "upstream_url": "http://search.cpan.org/"
                    "dist/Digest-Perl-MD5/"},
                    "status": True
                },
                "msg_id": "2015-364c5f35-c5c8-4d25-a367-29f34cd5418e",
                "timestamp": 1427635611,
                "topic": "org.fedoraproject.prod.pkgdb.package.monitor.update",
                "username": "apache"
            }
        },
        "msg_id": "2015-122c5e1a-b1f4-4403-8703-7b12f07456c0",
        "timestamp": 1427635619.0,
        "topic": "org.fedoraproject.prod.hotness.project.map"
    }


class TestHotnessMapFailJustOne(Base):
    """ These messages are published by a backend service called
    `the-new-hotness <https://github.com/fedora-infra/the-new-hotness>`_.
    It watches for new upstream release notifications from
    `release-monitoring.org <https://release-monitoring.org>`_ and in response
    it files bugs in `bugzilla <https://bugzilla.redhat.com>`_ and kicks off
    scratch builds in `koji <https://koji.fedoraproject.org/koji>`_.

    These kinds of messages get published when a new package gets added to
    Fedora and the-new-hotness **tries to add that package to
    release-monitoring.org**, but fails.
    """

    expected_title = "hotness.project.map"
    expected_subti = "hotness tried to map python-django-angular to the " + \
        "pre-existing upstream project django-angular, " + \
        "but failed for unknown reasons"
    expected_link = "https://release-monitoring.org/project/5510/"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://apps.fedoraproject.org/packages" + \
        "/images/icons/python-django-angular.png"
    expected_packages = set(['python-django-angular'])
    expected_usernames = set([])
    expected_objects = set([
        'projects/django-angular', 'packages/python-django-angular'])
    msg = {
        'msg_id': '2015-30c4b30d-ca69-4c95-bad9-8e4c0b5d8fdb',
        'timestamp': 1421445401,
        'topic': u'org.fedoraproject.prod.hotness.project.map',
        'msg': {
            'success': False,
            'project': {
                "backend": "PyPI",
                "created_on": 1421442402.0,
                "homepage": "https://pypi.python.org/pypi/django-angular",
                "id": 5510,
                "name": "django-angular",
                "regex": "",
                "updated_on": 1421442470.0,
                "version": "0.7.10",
                "version_url": "",
                "versions": [
                    "0.7.10"
                ]
            },
            'trigger': {
                u'msg_id': u'2015-b5cb92c6-9bdf-4807-ab29-2604ee93b407',
                u'timestamp': 1421445385,
                u'topic': u'org.fedoraproject.prod.pkgdb.package.new',
                u'msg': {
                    u'agent': u'limb',
                    u'package_listing': {
                        u'collection': {
                            u'branchname': u'master',
                            u'dist_tag': u'.fc22',
                            u'koji_name': u'rawhide',
                            u'name': u'Fedora',
                            u'status': u'Under Development',
                            u'version': u'devel'
                        },
                        u'critpath': False,
                        u'package': {
                            u'acls': [],
                            u'creation_date': 1421329015.0,
                            u'description': u'',
                            u'monitor': False,
                            u'name': u'python-django-angular',
                            u'review_url': u'https://bugzilla.redhat.com/'
                            '1182533',
                            u'status': u'Approved',
                            u'summary': u'Classes and utility functions to '
                            'integrate AngularJS with Django',
                            u'upstream_url': u'https://github.com/jrief/'
                            'django-angular',
                        },
                        u'point_of_contact': u'mrunge',
                        u'status': u'Approved',
                        u'status_change': 1421329016.0,
                    },
                    u'package_name': u'python-django-angular',
                },
            },
        },
    }


class TestHotnessMapSucceedJustOne(Base):
    """ These messages are published by a backend service called
    `the-new-hotness <https://github.com/fedora-infra/the-new-hotness>`_.
    It watches for new upstream release notifications from
    `release-monitoring.org <https://release-monitoring.org>`_ and in response
    it files bugs in `bugzilla <https://bugzilla.redhat.com>`_ and kicks off
    scratch builds in `koji <https://koji.fedoraproject.org/koji>`_.

    These kinds of messages get published when a new package gets added to
    Fedora and the-new-hotness **adds that package to
    release-monitoring.org**.
    """

    expected_title = "hotness.project.map"
    expected_subti = "hotness mapped python-django-angular to the " + \
        "pre-existing upstream project django-angular"
    expected_link = "https://release-monitoring.org/project/5510/"
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://apps.fedoraproject.org/packages" + \
        "/images/icons/python-django-angular.png"
    expected_packages = set(['python-django-angular'])
    expected_usernames = set([])
    expected_objects = set([
        'projects/django-angular', 'packages/python-django-angular'])
    msg = {
        'msg_id': '2015-30c4b30d-ca69-4c95-bad9-8e4c0b5d8fdb',
        'timestamp': 1421445401,
        'topic': u'org.fedoraproject.prod.hotness.project.map',
        'msg': {
            'success': True,
            'project': {
                "backend": "PyPI",
                "created_on": 1421442402.0,
                "homepage": "https://pypi.python.org/pypi/django-angular",
                "id": 5510,
                "name": "django-angular",
                "regex": "",
                "updated_on": 1421442470.0,
                "version": "0.7.10",
                "version_url": "",
                "versions": [
                    "0.7.10"
                ]
            },
            'trigger': {
                u'msg_id': u'2015-b5cb92c6-9bdf-4807-ab29-2604ee93b407',
                u'timestamp': 1421445385,
                u'topic': u'org.fedoraproject.prod.pkgdb.package.new',
                u'msg': {
                    u'agent': u'limb',
                    u'package_listing': {
                        u'collection': {
                            u'branchname': u'master',
                            u'dist_tag': u'.fc22',
                            u'koji_name': u'rawhide',
                            u'name': u'Fedora',
                            u'status': u'Under Development',
                            u'version': u'devel'
                        },
                        u'critpath': False,
                        u'package': {
                            u'acls': [],
                            u'creation_date': 1421329015.0,
                            u'description': u'',
                            u'monitor': False,
                            u'name': u'python-django-angular',
                            u'review_url': u'https://bugzilla.redhat.com/'
                            '1182533',
                            u'status': u'Approved',
                            u'summary': u'Classes and utility functions to '
                            'integrate AngularJS with Django',
                            u'upstream_url': u'https://github.com/jrief/'
                            'django-angular',
                        },
                        u'point_of_contact': u'mrunge',
                        u'status': u'Approved',
                        u'status_change': 1421329016.0,
                    },
                    u'package_name': u'python-django-angular',
                },
            },
        },
    }


class TestHotnessMapSucceedBrandNew(Base):
    """ These messages are published by a backend service called
    `the-new-hotness <https://github.com/fedora-infra/the-new-hotness>`_.
    It watches for new upstream release notifications from
    `release-monitoring.org <https://release-monitoring.org>`_ and in response
    it files bugs in `bugzilla <https://bugzilla.redhat.com>`_ and kicks off
    scratch builds in `koji <https://koji.fedoraproject.org/koji>`_.

    These kinds of messages get published when a new package gets added to
    Fedora and the-new-hotness **adds that package to
    release-monitoring.org**.
    """

    expected_title = "hotness.project.map"
    expected_subti = "hotness mapped python-django-angular to a " + \
        "brand-new upstream project"
    expected_link = u'https://bugzilla.redhat.com/1182533'
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://apps.fedoraproject.org/packages" + \
        "/images/icons/python-django-angular.png"
    expected_packages = set(['python-django-angular'])
    expected_usernames = set([])
    expected_objects = set(['packages/python-django-angular'])
    msg = {
        'msg_id': '2015-30c4b30d-ca69-4c95-bad9-8e4c0b5d8fdb',
        'timestamp': 1421445401,
        'topic': u'org.fedoraproject.prod.hotness.project.map',
        'msg': {
            'success': True,
            'trigger': {
                u'msg_id': u'2015-b5cb92c6-9bdf-4807-ab29-2604ee93b407',
                u'timestamp': 1421445385,
                u'topic': u'org.fedoraproject.prod.pkgdb.package.new',
                u'msg': {
                    u'agent': u'limb',
                    u'package_listing': {
                        u'collection': {
                            u'branchname': u'master',
                            u'dist_tag': u'.fc22',
                            u'koji_name': u'rawhide',
                            u'name': u'Fedora',
                            u'status': u'Under Development',
                            u'version': u'devel'
                        },
                        u'critpath': False,
                        u'package': {
                            u'acls': [],
                            u'creation_date': 1421329015.0,
                            u'description': u'',
                            u'monitor': False,
                            u'name': u'python-django-angular',
                            u'review_url': u'https://bugzilla.redhat.com/'
                            '1182533',
                            u'status': u'Approved',
                            u'summary': u'Classes and utility functions to '
                            'integrate AngularJS with Django',
                            u'upstream_url': u'https://github.com/jrief/'
                            'django-angular',
                        },
                        u'point_of_contact': u'mrunge',
                        u'status': u'Approved',
                        u'status_change': 1421329016.0,
                    },
                    u'package_name': u'python-django-angular',
                },
            },
        },
    }


class TestHotnessMapFailBrandNew(Base):
    """ These messages are published by a backend service called
    `the-new-hotness <https://github.com/fedora-infra/the-new-hotness>`_.
    It watches for new upstream release notifications from
    `release-monitoring.org <https://release-monitoring.org>`_ and in response
    it files bugs in `bugzilla <https://bugzilla.redhat.com>`_ and kicks off
    scratch builds in `koji <https://koji.fedoraproject.org/koji>`_.

    These kinds of messages get published when a new package gets added to
    Fedora and the-new-hotness **tries to add that package to
    release-monitoring.org** but fails for unknown reasons.
    """

    expected_title = "hotness.project.map"
    expected_subti = "hotness tried to map python-django-angular to a " + \
        "brand-new upstream project, but failed for unknown reasons"
    expected_link = u'https://bugzilla.redhat.com/1182533'
    expected_icon = "https://apps.fedoraproject.org/packages/" + \
        "images/icons/package_128x128.png"
    expected_secondary_icon = "https://apps.fedoraproject.org/packages" + \
        "/images/icons/python-django-angular.png"
    expected_packages = set(['python-django-angular'])
    expected_usernames = set([])
    expected_objects = set(['packages/python-django-angular'])
    msg = {
        'msg_id': '2015-30c4b30d-ca69-4c95-bad9-8e4c0b5d8fdb',
        'timestamp': 1421445401,
        'topic': u'org.fedoraproject.prod.hotness.project.map',
        'msg': {
            'success': False,
            'trigger': {
                u'msg_id': u'2015-b5cb92c6-9bdf-4807-ab29-2604ee93b407',
                u'timestamp': 1421445385,
                u'topic': u'org.fedoraproject.prod.pkgdb.package.new',
                u'msg': {
                    u'agent': u'limb',
                    u'package_listing': {
                        u'collection': {
                            u'branchname': u'master',
                            u'dist_tag': u'.fc22',
                            u'koji_name': u'rawhide',
                            u'name': u'Fedora',
                            u'status': u'Under Development',
                            u'version': u'devel'
                        },
                        u'critpath': False,
                        u'package': {
                            u'acls': [],
                            u'creation_date': 1421329015.0,
                            u'description': u'',
                            u'monitor': False,
                            u'name': u'python-django-angular',
                            u'review_url': u'https://bugzilla.redhat.com/'
                            '1182533',
                            u'status': u'Approved',
                            u'summary': u'Classes and utility functions to '
                            'integrate AngularJS with Django',
                            u'upstream_url': u'https://github.com/jrief/'
                            'django-angular',
                        },
                        u'point_of_contact': u'mrunge',
                        u'status': u'Approved',
                        u'status_change': 1421329016.0,
                    },
                    u'package_name': u'python-django-angular',
                },
            },
        },
    }


add_doc(locals())

if __name__ == '__main__':
    unittest.main()



# This file is part of fedmsg.
# Copyright (C) 2012 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Ralph Bean <rbean@redhat.com>
#
""" Tests for planet messages """

import unittest

from fedmsg.tests.test_meta import Base

from .common import add_doc


class TestPlanetNewPost(Base):
    """ The `Fedora Planet <https://planet.fedoraproject.org/>`_ publishes
    messages of this topic whenever a new blog post is found.  Cool!
    """

    expected_title = "planet.post.new"
    expected_subti = 'ralph posted "Test Post 6"'
    expected_link = "http://threebean.org/blog/test-post-6"
    expected_icon = 'https://apps.fedoraproject.org/img/icons/planet_logo.png'
    expected_secondary_icon = ("https://secure.gravatar.com/avatar/"
                               "ba940b433c2695635d32d2c4aec00540?s=140")
    expected_packages = set([])
    expected_usernames = set(['ralph'])
    expected_objects = set(['threebean.org/blog/test-post-6'])
    msg = {
        "username": "planet-user",
        "i": 1,
        "timestamp": 1359579067.6178019,
        "topic": "org.fedoraproject.prod.planet.post.new",
        "msg": {
            "username": "ralph",
            "post": {
                "summary_detail": {
                    "base": "http://threebean.org/blog/category/"
                    "fedora/feed/index.xml",
                    "type": "text/html",
                    "value": "Test Post 6",
                    "language": None
                },
                "updated_parsed": 1359576000.0,
                "links": [
                    {
                        "href": "http://threebean.org/blog/test-post-6",
                        "type": "text/html",
                        "rel": "alternate"
                    }
                ],
                "tags": [
                    {
                        "term": "fedora",
                        "scheme": None,
                        "label": None
                    }
                ],
                "title": "Test Post 6",
                "updated": "Wed, 30 Jan 2013 15:00:00 EST",
                "summary": "Test Post 6",
                "content": [
                    {
                        "base": "http://threebean.org/blog/category/"
                        "fedora/feed/index.xml",
                        "type": "text/html",
                        "value": "<div class=\"document\">\n<p>Another "
                        "test post for fedmsg+fedoraplanet.</p>\n</div>",
                        "language": None
                    }
                ],
                "guidislink": False,
                "title_detail": {
                    "base": "http://threebean.org/blog/category/"
                    "fedora/feed/index.xml",
                    "type": "text/html",
                    "value": "Test Post 6",
                    "language": None
                },
                "link": "http://threebean.org/blog/test-post-6",
                "id": "http://threebean.org/blog/test-post-6"
            },
            "name": "Ralph Bean",
            "face": "https://secure.gravatar.com/avatar/"
            "ba940b433c2695635d32d2c4aec00540?s=140"
        }
    }


add_doc(locals())

if __name__ == '__main__':
    unittest.main()
